@@ -2,9 +2,11 @@
 
 import enum
 import os
+import re
 import subprocess
 from typing import Union
-from . import helper, user_input_handler
+
+from . import helper, user_input_handler, config_manager
 
 
 class ADBExceptionTypes(enum.Enum):
@@ -37,6 +39,34 @@ def adb_pull(package_name: str, device_file_path: str, local_file_path: str):
     run_adb_command(f'pull "{path}" {local_file_path}')
 
 
+def find_game_versions() -> list[str]:
+    """
+    Find installed game versions
+
+    Returns:
+        list[str]: List of game versions
+    """
+    package_name = "jp.co.ponos.battlecats"
+    try:
+        run_adb_command("devices")
+    except ADBException as exception:
+        return adb_err_handler(exception)
+    try:
+        output = str(
+            subprocess.run(
+                "adb shell ls /data/data/", capture_output=True, check=True
+            ).stdout
+        )
+    except subprocess.CalledProcessError:
+        return []
+    package_names: list[str] = re.findall(f"{package_name}..", output)
+    for i, package_name in enumerate(package_names):
+        package_names[i] = package_name.replace("  ", "jp").replace(
+            "jp.co.ponos.battlecats", ""
+        )
+    return package_names
+
+
 def adb_push(package_name: str, local_file_path: str, device_file_path: str):
     """Push a file to a device"""
 
@@ -62,12 +92,21 @@ def adb_run_process(package_name: str):
 
     run_adb_command(f"shell monkey -p {package_name} -v 1")
 
+
 def adb_reboot():
     """Reboot adb server"""
 
+    helper.run_in_background(adb_reboot_background)
+
+
+def adb_reboot_background():
+    """
+    Reboot adb server in background
+    """
     adb_kill_server()
     is_adb_installed()
 
+
 def adb_root():
     """Start adb server as root"""
 
@@ -108,7 +147,9 @@ def adb_kill_server():
     """Kill ADB server"""
 
     try:
-        subprocess.run("adb kill-server", shell=True, check=True, text=True, capture_output=True)
+        subprocess.run(
+            "adb kill-server", shell=True, check=True, text=True, capture_output=True
+        )
     except subprocess.CalledProcessError as err:
         adb_error_handler(err)
 
@@ -140,19 +181,27 @@ def find_adb_path() -> Union[str, None]:
         "Program Files (x86)\\Nox\\bin",
         "adb",
     ]
+    found_paths: list[str] = []
     for drive_letter in drive_letters:
         for path in paths:
             path = f"{drive_letter}:\\{path}"
             if os.path.exists(path):
+                found_paths.append(path)
+    if found_paths:
+        for path in found_paths:
+            if "adb" not in path:
                 return path
+        return found_paths[0]
 
     return None
 
+
 def if_windows() -> bool:
     """Check if windows"""
 
     return os.name == "nt"
 
+
 def add_to_path() -> None:
     """Try to add adb to path environment variable automatically"""
 
@@ -173,8 +222,15 @@ def add_to_path() -> None:
             adb_path = os.path.dirname(adb_path)
 
     print(f"Adding {adb_path} to your path environment variable")
-    subprocess.run(f"set PATH={adb_path};%PATH%", shell=True, check=True)
-    subprocess.run(f"setx PATH {adb_path};%PATH%", shell=True, check=True)
+    backup = os.environ["PATH"]
+    backup_path = os.path.join(config_manager.get_app_data_folder(), "path_backup.txt")
+    helper.write_file_string(backup_path, backup)
+    helper.colored_text(
+        f"Your old PATH environment variable has been backed up to &{backup_path}&"
+    )
+    subprocess.run(
+        f'setx PATH "{adb_path};%PATH%"', shell=True, check=True, text=True
+    )
     print("Successfully added adb to path")
 
 
@@ -228,11 +284,11 @@ def adb_pull_save_data(game_version: str) -> str:
         adb_pull(
             get_package_name(game_version),
             "files/SAVE_DATA",
-            helper.get_default_save_name(),
+            helper.get_save_path_home(),
         )
     except ADBException as err:
         adb_err_handler(err)
-    return helper.get_default_save_name()
+    return helper.get_save_path_home()
 
 
 def adb_push_save_data(game_version: str, path: str) -> None:
