@@ -32,14 +32,44 @@ def get_config_file() -> dict[str, Any]:
     Returns:
         dict: Config file
     """
-    config_file = os.path.join(get_app_data_folder(), "config.yaml")
-    if not os.path.exists(config_file):
-        create_config_file()
+    config_file = get_config_path()
     with open(config_file, "r", encoding="utf-8") as file:
         config = yaml.safe_load(file)
     return config
 
 
+def get_config_path() -> str:
+    """
+    Get the path to the config file
+
+    Returns:
+        str: Path to config file
+    """
+    config_path_path = helper.get_file("config_path.txt")
+    helper.create_dirs(os.path.dirname(config_path_path))
+    if not os.path.exists(config_path_path):
+        helper.write_file_string(config_path_path, "")
+
+    config_path = helper.read_file_string(config_path_path)
+    if config_path == "":
+        config_path = os.path.join(get_app_data_folder(), "config.yaml")
+    if not os.path.exists(config_path):
+        create_config_file(config_path)
+    return config_path
+
+
+def set_config_path(path: str):
+    """
+    Set the path to the config file
+
+    Args:
+        path (str): Path to config file
+    """
+    helper.write_file_string(helper.get_file("config_path.txt"), path)
+    if not os.path.exists(path):
+        create_config_file()
+
+
 def get_config_value(setting: str) -> Any:
     """
     Get a config setting
@@ -51,7 +81,11 @@ def get_config_value(setting: str) -> Any:
         Any: Value of setting
     """
     config = get_config_file()
-    return config[setting]
+    setting_data = config.get(setting)
+    if setting_data is None:
+        create_config_file()
+        return get_config_value(setting)
+    return setting_data
 
 
 def set_config_setting_category(category: str, key: str, value: Any) -> None:
@@ -64,9 +98,7 @@ def set_config_setting_category(category: str, key: str, value: Any) -> None:
     """
     config = get_config_file()
     config[category][key] = value
-    with open(
-        os.path.join(get_app_data_folder(), "config.yaml"), "w", encoding="utf-8"
-    ) as file:
+    with open(get_config_path(), "w", encoding="utf-8") as file:
         yaml.safe_dump(config, file)
 
 
@@ -80,32 +112,32 @@ def set_config_setting(setting: str, value: Any) -> None:
     """
     config = get_config_file()
     config[setting] = value
-    with open(
-        os.path.join(get_app_data_folder(), "config.yaml"), "w", encoding="utf-8"
-    ) as file:
+    with open(get_config_path(), "w", encoding="utf-8") as file:
         yaml.safe_dump(config, file)
 
 
-def create_config_file() -> None:
+def create_config_file(config_path: Optional[str] = None) -> None:
     """
     Create the config file if it doesn't exist
     """
-    config_file = os.path.join(get_app_data_folder(), "config.yaml")
+    if config_path is None:
+        config_file = get_config_path()
+    else:
+        config_file = config_path
     file_data = "# Configuration file for BCSFE\n"
     file_data += "# This file is automatically created when the program is run for the first time\n"
     file_data += "# You can edit this file to change the settings\n"
     file_data += "# You can also edit the settings in the program\n#\n"
     file_data += "# The following settings are available:\n#\n"
-    file_data += """DEFAULT_GAME_VERSION: "" # The default game version when downloading / pulling / loading save data. E.g en, jp, kr, tw. Empty means the game version is not specified and will be asked for when needed.
+    file_data += """DEFAULT_COUNTRY_CODE: "" # The default game version when downloading / pulling / loading save data. E.g en, jp, kr, tw. Empty means the game version is not specified and will be asked for when needed.
 DEFAULT_SAVE_FILE_PATH: "SAVE_DATA" # The default file path for your save data when saving changes / downloading save data / pulling etc
-
+FIXED_SAVE_PATH: False # If True, the save path will be from your user's folder / home folder. If False, the save path will be where the program is run from
 EDITOR:
   DISABLE_MAXES: False # Allows you to edit the level / amount of items past the max amount.
   SHOW_BAN_WARNING: True # Show a warning when editing bannable items.
   SHOW_CATEGORIES: True # Show the categories in the feature list, instead of a long list.
   SHOW_FEATURE_SELECT_EXPLANATION: True # Show an explanation of how to select a feature.
   ONLY_GET_EN_DATA: False # Only get the en version of the game data even if the save is jp, use if you can't read japanese
-  USE_ARROW_KEYS_FOR_FEATURE_SELECT: False # Use the arrow keys to select a feature instead of typing the number
 
 START_UP:
   CHECK_FOR_UPDATES: True # Check for updates on startup
@@ -123,7 +155,6 @@ SERVER:
   WIPE_TRACKED_ITEMS_ON_START: True # Wipe all tracked items stored when the editor starts up - if disabled, it allows you to upload metadata changes after you exit and re-enter the editor.
 """
 
-    
     helper.write_file_string(config_file, file_data)
 
 
@@ -154,11 +185,11 @@ def edit_default_gv(_: Any) -> None:
     """
     Edit the default game version
     """
-    default_gv = get_config_value("DEFAULT_GAME_VERSION")
+    default_gv = get_config_value("DEFAULT_COUNTRY_CODE")
     default_gv = user_input_handler.colored_input(
         f"Enter the default game version. Current value: {default_gv} Leave blank to not specify a default game version:",
     )
-    set_config_setting("DEFAULT_GAME_VERSION", default_gv)
+    set_config_setting("DEFAULT_COUNTRY_CODE", default_gv)
 
 
 def edit_default_save_file_path(_: Any) -> None:
@@ -173,6 +204,20 @@ def edit_default_save_file_path(_: Any) -> None:
         "DEFAULT_SAVE_FILE_PATH", os.path.join(default_save_file_path, "SAVE_DATA")
     )
 
+def edit_fixed_save_path(_: Any) -> None:
+    """
+    Edit the fixed save path
+    """
+    fixed_save_path = get_config_value("FIXED_SAVE_PATH")
+    fixed_save_path = user_input_handler.colored_input(
+        f"Enter if the save path should be fixed. Current value: {fixed_save_path} (True/False):",
+    )
+    if fixed_save_path.lower() == "true":
+        fixed_save_path = True
+    else:
+        fixed_save_path = False
+    set_config_setting("FIXED_SAVE_PATH", fixed_save_path)
+
 
 def edit_editor_settings(_: Any) -> None:
     """
@@ -184,7 +229,6 @@ def edit_editor_settings(_: Any) -> None:
         "SHOW_CATEGORIES",
         "SHOW_FEATURE_SELECT_EXPLANATION",
         "ONLY_GET_EN_DATA",
-        "USE_ARROW_KEYS_FOR_FEATURE_SELECT",
     ]
     option_values = [get_config_value_category("EDITOR", option) for option in options]
     ids = user_input_handler.select_not_inc(options, "select", option_values)
@@ -238,6 +282,7 @@ def edit_start_up_settings(_: Any) -> None:
         else:
             raise Exception(f"Unsupported option type {option_type}")
 
+
 def edit_save_changes_settings(_: Any) -> None:
     """
     Edit the save changes settings
@@ -246,10 +291,10 @@ def edit_save_changes_settings(_: Any) -> None:
         "SAVE_CHANGES_ON_EDIT",
         "ALWAYS_EXPORT_JSON",
     ]
-    option_values = [get_config_value_category("SAVE_CHANGES", option) for option in options]
-    ids = user_input_handler.select_not_inc(
-        options, "select", option_values
-    )
+    option_values = [
+        get_config_value_category("SAVE_CHANGES", option) for option in options
+    ]
+    ids = user_input_handler.select_not_inc(options, "select", option_values)
     for option_id in ids:
         option_name = options[option_id]
         enable = (
@@ -260,6 +305,7 @@ def edit_save_changes_settings(_: Any) -> None:
         )
         set_config_setting_category("SAVE_CHANGES", option_name, enable)
 
+
 def edit_server_settings(_: Any) -> None:
     """
     Edit the server settings
@@ -269,9 +315,7 @@ def edit_server_settings(_: Any) -> None:
         "WIPE_TRACKED_ITEMS_ON_START",
     ]
     option_values = [get_config_value_category("SERVER", option) for option in options]
-    ids = user_input_handler.select_not_inc(
-        options, "select", option_values
-    )
+    ids = user_input_handler.select_not_inc(options, "select", option_values)
     for option_id in ids:
         option_name = options[option_id]
         enable = (
@@ -280,4 +324,14 @@ def edit_server_settings(_: Any) -> None:
             )
             == "1"
         )
-        set_config_setting_category("SERVER", option_name, enable)
\ No newline at end of file
+        set_config_setting_category("SERVER", option_name, enable)
+
+
+def edit_config_path(_: Any) -> None:
+    """
+    Edit the config path
+    """
+    config_path = os.path.dirname(get_config_path())
+    config_path = helper.select_dir("Select the config path", config_path)
+    config_path = os.path.join(config_path, "config.yaml")
+    set_config_path(config_path)
