@@ -1,6 +1,6 @@
 """Handler for basic, items that work in a common way"""
 from typing import Any
-from ... import helper, item, managed_item
+from ... import item, managed_item
 
 
 def edit_cat_food(save_stats: dict[str, Any]) -> dict[str, Any]:
@@ -93,10 +93,12 @@ def edit_platinum_tickets(save_stats: dict[str, Any]) -> dict[str, Any]:
 def edit_platinum_shards(save_stats: dict[str, Any]) -> dict[str, Any]:
     """Handler for editing platinum shards"""
 
+    ticket_amount = save_stats["platinum_tickets"]["Value"]
+    max_value = 99 - (ticket_amount * 10)
     platinum_shards = item.Item(
         name="Platinum Shards",
         value=save_stats["platinum_shards"]["Value"],
-        max_value=99,
+        max_value=max_value,
         edit_name="value",
     )
     platinum_shards.edit()
@@ -155,27 +157,6 @@ def edit_battle_items(save_stats: dict[str, Any]) -> dict[str, Any]:
     return save_stats
 
 
-def edit_catseyes(save_stats: dict[str, Any]) -> dict[str, Any]:
-    """Handler for editing catseyes"""
-
-    catseyes = item.create_item_group(
-        names=[
-            "Special",
-            "Rare",
-            "Super Rare",
-            "Uber Super Rare",
-            "Legend Rare",
-        ],
-        values=save_stats["catseyes"],
-        maxes=9999,
-        edit_name="value",
-        group_name="Catseyes",
-    )
-    catseyes.edit()
-    save_stats["catseyes"] = catseyes.values
-    return save_stats
-
-
 def edit_engineers(save_stats: dict[str, Any]) -> dict[str, Any]:
     """Handler for editing ototo engineers"""
 
@@ -341,11 +322,7 @@ def edit_dojo_score(save_stats: dict[str, Any]) -> dict[str, Any]:
     """Handler for editing the dojo score"""
 
     if not save_stats["dojo_data"]:
-        helper.colored_text(
-            "No catclaw dojo data found\nPlease enter the catclaw dojo menu and try again",
-            base=helper.RED,
-        )
-        return save_stats
+        save_stats["dojo_data"] = {0: {0: 0}}
 
     dojo_score = item.Item(
         name="Dojo Score",
@@ -354,5 +331,5 @@ def edit_dojo_score(save_stats: dict[str, Any]) -> dict[str, Any]:
         edit_name="value",
     )
     dojo_score.edit()
-    save_stats["dojo_data"][0][0] = dojo_score.value
+    save_stats["dojo_data"][0][0] = int(dojo_score.value)
     return save_stats
