@@ -1,24 +1,32 @@
 """Handler to edit cat talents"""
-from typing import Any
+from typing import Any, Optional
 
-from ... import helper, item, csv_handler, game_data_getter
+from ... import helper, item, csv_handler, game_data_getter, user_input_handler
 from . import cat_id_selector
 
 
-def get_talent_data(save_stats: dict[str, Any]) -> dict[Any, Any]:
+def get_talent_data(save_stats: dict[str, Any]) -> Optional[dict[Any, Any]]:
     """Get talent data for all cats"""
 
+    file_data = game_data_getter.get_file_latest(
+        "DataLocal", "SkillAcquisition.csv", helper.check_data_is_jp(save_stats)
+    )
+    if file_data is None:
+        helper.error_text("Failed to get talent data")
+        return None
     talent_data_raw = helper.parse_int_list_list(
         csv_handler.parse_csv(
-            game_data_getter.get_file_latest(
-                "DataLocal", "SkillAcquisition.csv", helper.check_data_is_jp(save_stats)
-            ).decode("utf-8"),
+            file_data.decode("utf-8"),
         )
     )
+    file_data = game_data_getter.get_file_latest(
+        "resLocal", "SkillDescriptions.csv", helper.check_data_is_jp(save_stats)
+    )
+    if file_data is None:
+        helper.error_text("Failed to get talent names")
+        return None
     talent_names = csv_handler.parse_csv(
-        game_data_getter.get_file_latest(
-            "resLocal", "SkillDescriptions.csv", helper.check_data_is_jp(save_stats)
-        ).decode("utf-8"),
+        file_data.decode("utf-8"),
         helper.get_text_splitter(helper.check_data_is_jp(save_stats)),
     )
     columns = helper.int_to_str_ls(talent_data_raw[0])
@@ -93,14 +101,14 @@ def get_cat_talents(
 
     data: dict[Any, Any] = {}
     letter_order = find_order(cat_talents, cat_talent_data)
-    for i in range(len(cat_talents) - 1):
+    for i, letter in enumerate(letter_order):
         cat_data = {}
-        if letter_order[i] == "F":
+        if letter == "F":
             text_id_str = "tFxtID_F"  # ponos made a typo, should be textID_F
         else:
-            text_id_str = f"textID_{letter_order[i]}"
+            text_id_str = f"textID_{letter}"
         cat_data["name"] = cat_talent_data[text_id_str].strip("\n")
-        cat_data["max"] = int(cat_talent_data[f"MAXLv_{letter_order[i]}"])
+        cat_data["max"] = int(cat_talent_data[f"MAXLv_{letter}"])
         if cat_data["max"] == 0:
             cat_data["max"] = 1
         data[i] = cat_data
@@ -124,11 +132,21 @@ def get_talent_levels(
 
 def max_all_talents(save_stats: dict[str, Any]):
     """Max all talents for all cats"""
+    max_all = (
+        user_input_handler.colored_input(
+            "Do you want to max talents or reset talents? (&m&/&r&):"
+        )
+        == "m"
+    )
+    if not max_all:
+        return remove_all_talents(save_stats)
     talents = save_stats["talents"]
 
     ids = cat_id_selector.select_cats(save_stats)
 
     talent_data = get_talent_data(save_stats)
+    if talent_data is None:
+        return save_stats
     cat_talents_levels: list[int] = []
     for cat_id in ids:
         if cat_id not in talents or cat_id not in talent_data:
@@ -143,6 +161,37 @@ def max_all_talents(save_stats: dict[str, Any]):
     return save_stats
 
 
+def remove_all_talents(save_stats: dict[str, Any]) -> dict[str, Any]:
+    """
+    Remove all talents for all cats
+
+    Args:
+        save_stats (dict[str, Any]): The save stats
+
+    Returns:
+        dict[str, Any]: The save stats
+    """
+    talents = save_stats["talents"]
+
+    ids = cat_id_selector.select_cats(save_stats)
+
+    talent_data = get_talent_data(save_stats)
+    if talent_data is None:
+        return save_stats
+    cat_talents_levels: list[int] = []
+    for cat_id in ids:
+        if cat_id not in talents or cat_id not in talent_data:
+            continue
+        cat_talents = talents[cat_id]
+        cat_talents_levels = get_talent_levels(talent_data, talents, cat_id)
+        for i in range(len(cat_talents_levels)):
+            cat_talents[i + 1]["level"] = 0
+        save_stats["talents"] = talents
+
+    print("Successfully removed talents")
+    return save_stats
+
+
 def edit_talents_individual(save_stats: dict[str, Any]) -> dict[str, Any]:
     """Handler for editing talents"""
 
@@ -150,12 +199,18 @@ def edit_talents_individual(save_stats: dict[str, Any]) -> dict[str, Any]:
     ids = cat_id_selector.select_cats(save_stats)
 
     talent_data = get_talent_data(save_stats)
+    if talent_data is None:
+        return save_stats
     cat_talents_levels: list[int] = []
     for cat_id in ids:
         if cat_id not in talents or cat_id not in talent_data:
             # don't spam the user with messages if they selected alot of ids at once
             if len(ids) < 20:
-                helper.colored_text(f"Error cat &{cat_id}& does not have any talents", helper.RED, helper.WHITE)
+                helper.colored_text(
+                    f"Error cat &{cat_id}& does not have any talents",
+                    helper.RED,
+                    helper.WHITE,
+                )
             continue
         cat_talent_data = talent_data[cat_id]
         cat_talents = talents[cat_id]
