@@ -1,16 +1,15 @@
 """Handler for selecting story levels"""
-from typing import Union
+from typing import Optional
 
 from ... import user_input_handler, helper
 from . import main_story
 
+
 def select_specific_chapters() -> list[int]:
     """Select specific levels"""
 
     print("What chapters do you want to select?")
-    ids = user_input_handler.select_not_inc(
-        main_story.CHAPTERS, "clear"
-    )
+    ids = user_input_handler.select_not_inc(main_story.CHAPTERS, "clear")
     return ids
 
 
@@ -26,7 +25,7 @@ def get_option():
 
 
 def select_levels(
-    chapter_id: Union[int, None], forced_option: Union[int, None] = None, total: int = 48
+    chapter_id: Optional[int], forced_option: Optional[int] = None, total: int = 48
 ) -> list[int]:
     """Select levels"""
 
@@ -43,7 +42,7 @@ def select_levels(
     return []
 
 
-def select_specific_levels(chapter_id: Union[int, None], total: int) -> list[int]:
+def select_specific_levels(chapter_id: Optional[int], total: int) -> list[int]:
     """Select specific levels"""
 
     print("What levels do you want to select?")
@@ -51,12 +50,14 @@ def select_specific_levels(chapter_id: Union[int, None], total: int) -> list[int
         helper.colored_text(
             f"Chapter: &{chapter_id+1}& : &{main_story.CHAPTERS[chapter_id]}&"
         )
-    ids = user_input_handler.get_range_ids("Level ids (e.g &1&=korea, &2&=mongolia)", total)
+    ids = user_input_handler.get_range_ids(
+        "Level ids (e.g &1&=korea, &2&=mongolia)", total
+    )
     ids = helper.check_clamp(ids, total, 1, -1)
     return ids
 
 
-def select_levels_up_to(chapter_id: Union[int, None], total: int) -> list[int]:
+def select_levels_up_to(chapter_id: Optional[int], total: int) -> list[int]:
     """Select levels up to a certain level"""
 
     print("What levels do you want to select?")
@@ -75,3 +76,24 @@ def select_all(total: int) -> list[int]:
     """Select all levels"""
 
     return list(range(0, total))
+
+
+def select_level_progress(chapter_id: Optional[int], total: int, examples: Optional[list[str]] = None) -> int:
+    """Select level progress"""
+
+    if examples is None:
+        examples = [
+            "korea",
+            "mongolia",
+        ]
+
+    print("What level do you want to clear up to and including?")
+    if chapter_id is not None:
+        helper.colored_text(
+            f"Chapter: &{chapter_id+1}& : &{main_story.CHAPTERS[chapter_id]}&"
+        )
+    progress = user_input_handler.get_int(
+        f"Enter the stage id that you want to clear/unclear (e.g &1&={examples[0]} cleared, &2&={examples[0]} &and& {examples[1]} cleared, &{total}&=all, &0&=unclear all)?:"
+    )
+    progress = helper.clamp(progress, 0, total)
+    return progress
