@@ -1,15 +1,19 @@
 """Handler for editing catnip missions"""
-from typing import Any
+from typing import Any, Optional
 
 from ... import user_input_handler, game_data_getter, csv_handler, helper
 
 
-def get_mission_conditions(is_jp: bool) -> dict[Any, Any]:
+def get_mission_conditions(is_jp: bool) -> Optional[dict[Any, Any]]:
     """Get the mission data and what you need to do to complete it"""
 
-    mission_condition_data = game_data_getter.get_file_latest(
+    file_data = game_data_getter.get_file_latest(
         "DataLocal", "Mission_Condition.csv", is_jp
-    ).decode("utf-8")
+    )
+    if file_data is None:
+        helper.error_text("Failed to get mission conditions")
+        return None
+    mission_condition_data = file_data.decode("utf-8")
     mission_conditions_list = helper.parse_int_list_list(
         csv_handler.parse_csv(mission_condition_data)
     )
@@ -25,12 +29,14 @@ def get_mission_conditions(is_jp: bool) -> dict[Any, Any]:
     return mission_conditions
 
 
-def get_mission_names(is_jp: bool) -> dict[int, Any]:
+def get_mission_names(is_jp: bool) -> Optional[dict[int, Any]]:
     """Get all mission names"""
 
-    mission_name = game_data_getter.get_file_latest(
-        "resLocal", "Mission_Name.csv", is_jp
-    ).decode("utf-8")
+    file_data = game_data_getter.get_file_latest("resLocal", "Mission_Name.csv", is_jp)
+    if file_data is None:
+        helper.error_text("Failed to get mission names")
+        return None
+    mission_name = file_data.decode("utf-8")
     mission_name_list = mission_name.split("\n")
     mission_names: dict[Any, Any] = {}
     for mission_name in mission_name_list:
@@ -38,7 +44,9 @@ def get_mission_names(is_jp: bool) -> dict[int, Any]:
         if not helper.check_int(line_data[0]):
             continue
         mission_id = int(line_data[0])
-        mission_names[mission_id] = line_data[1]
+        name = line_data[1]
+        name = name.replace("&", "\\&")
+        mission_names[mission_id] = name
     return mission_names
 
 
@@ -60,7 +68,7 @@ def get_mission_ids(
     """Get the mission ids and names from the conditions"""
 
     mission_ids_to_use: list[int] = []
-    for mission_id in missions["flags"]:
+    for mission_id in missions["states"]:
         if mission_id in conditions:
             mission_ids_to_use.append(mission_id)
 
@@ -82,13 +90,13 @@ def set_missions(
         mission_id = mission_ids_to_use[mission_id]
         if re_claim:
             claim = True
-        elif not re_claim and missions["flags"][mission_id] != 4:
+        elif not re_claim and missions["states"][mission_id] != 4:
             claim = True
         else:
             claim = False
         if claim:
-            missions["flags"][mission_id] = 2
-            missions["values"][mission_id] = conditions[mission_id]["progress_count"]
+            missions["states"][mission_id] = 2
+            missions["requirements"][mission_id] = conditions[mission_id]["progress_count"]
     return missions
 
 
@@ -100,9 +108,10 @@ def edit_missions(save_stats: dict[str, Any]) -> dict[str, Any]:
     names = get_mission_names(helper.check_data_is_jp(save_stats))
     conditions = get_mission_conditions(helper.check_data_is_jp(save_stats))
 
-    mission_ids_to_use, names_to_use = get_mission_ids(
-        missions, conditions, names
-    )
+    if names is None or conditions is None:
+        return save_stats
+
+    mission_ids_to_use, names_to_use = get_mission_ids(missions, conditions, names)
 
     ids = user_input_handler.select_not_inc(
         options=names_to_use,
@@ -114,9 +123,7 @@ def edit_missions(save_stats: dict[str, Any]) -> dict[str, Any]:
         )
         == "1"
     )
-    missions = set_missions(
-        missions, ids, conditions, mission_ids_to_use, re_claim
-    )
+    missions = set_missions(missions, ids, conditions, mission_ids_to_use, re_claim)
     save_stats["missions"] = missions
     print("Successfully completed missions")
     return save_stats
