@@ -41,13 +41,16 @@ def fix_elsewhere_old(save_stats: dict[str, Any]) -> dict[str, Any]:
 
 FEATURES: dict[str, Any] = {
     "Save Management": {
+        "Save Save" : save_management.save.save_save,
         "Save changes and upload to game servers (get transfer and confirmation codes)": save_management.server_upload.save_and_upload,
-        "Save changes and exit": save_management.save_and_exit.save_and_exit,
-        "Save changes and push save data to the game (don't re-open game)": save_management.save_and_exit.save_and_push,
-        "Save changes and push save data to the game (re-open game)": save_management.save_and_exit.save_and_push_rerun,
+        "Save changes to file": save_management.save.save,
+        "Save changes and push save data to the game (don't re-open game)": save_management.save.save_and_push,
+        "Save changes and push save data to the game (re-open game)": save_management.save.save_and_push_rerun,
         "Export save data as json": save_management.other.export,
         "Clear save data (used to generate a new account without re-installing the game)": save_management.other.clear_data,
-        "Upload tracked bannable items (This is done automatically when saving and exiting)": save_management.server_upload.upload_metadata,
+        "Upload tracked bannable items (This is done automatically when saving or exiting)": save_management.server_upload.upload_metadata,
+        "Load save data" : save_management.load.select,
+        #"Manage Presets": preset_handler.preset_manager,
     },
     "Items": {
         "Cat Food": basic.basic_items.edit_cat_food,
@@ -62,10 +65,11 @@ FEATURES: dict[str, Any] = {
         "NP": basic.basic_items.edit_np,
         "Leadership": basic.basic_items.edit_leadership,
         "Battle Items": basic.basic_items.edit_battle_items,
-        "Catseyes": basic.basic_items.edit_catseyes,
+        "Catseyes": basic.catseyes.edit_catseyes,
         "Cat Fruit / Behemoth Stones": basic.catfruit.edit_catfruit,
         "Talent Orbs": basic.talent_orbs.edit_talent_orbs,
         "Catamins": basic.basic_items.edit_catamins,
+        "Item Schemes (Allows you to get unbannable items)": other.scheme_item.edit_scheme_data,
     },
     "Gamatoto / Ototo": {
         "Ototo Engineers": basic.basic_items.edit_engineers,
@@ -112,20 +116,26 @@ FEATURES: dict[str, Any] = {
         "Event Stages": levels.event_stages.event_stages,
         "Stories of Legend": levels.event_stages.stories_of_legend,
         "Uncanny Legends": levels.uncanny.edit_uncanny,
-        "Aku Realm/Gates": levels.aku.edit_aku,
+        "Aku Realm/Gates Clearing": levels.aku.edit_aku,
+        "Unlock the Aku Realm/Gates": levels.unlock_aku_realm.unlock_aku_realm,
         "Gauntlets": levels.gauntlet.edit_gauntlet,
+        "Collab Gauntlets": levels.gauntlet.edit_collab_gauntlet,
+        "Towers": levels.towers.edit_tower,
+        "Behemoth Culling": levels.behemoth_culling.edit_behemoth_culling,
         "Into the Future Timed Scores": levels.itf_timed_scores.timed_scores,
         "Challenge Battle Score": basic.basic_items.edit_challenge_battle,
-        "Towers": levels.towers.edit_tower,
         "Clear Tutorial": levels.clear_tutorial.clear_tutorial,
         "Catclaw Dojo Score (Hall of Initiates)": basic.basic_items.edit_dojo_score,
+        "Add Enigma Stages": levels.enigma_stages.edit_enigma_stages,
+        "Allow the filibuster stage to be recleared" : levels.allow_filibuster_clearing.allow_filibuster_clearing,
+        "Legend Quest": levels.legend_quest.edit_legend_quest,
     },
     "Inquiry Code / Token / Account": {
         "Inquiry Code": basic.basic_items.edit_inquiry_code,
         "Token": basic.basic_items.edit_token,
         "Fix elsewhere error / Unban account": other.fix_elsewhere.fix_elsewhere,
         "Old Fix elsewhere error / Unban account (needs 2 save files)": fix_elsewhere_old,
-        "Create a new account / Duplicate account": other.create_new_account.create_new_account,
+        "Generate a new inquiry code and token": other.create_new_account.create_new_account,
     },
     "Other": {
         "Rare Gacha Seed": basic.basic_items.edit_rare_gacha_seed,
@@ -136,19 +146,30 @@ FEATURES: dict[str, Any] = {
         "Unlock / Remove Enemy Guide Entries": other.unlock_enemy_guide.enemy_guide,
         "Catnip Challenges / Missions": other.missions.edit_missions,
         "Normal Ticket Max Trade Progress (allows for unbannable rare tickets)": other.trade_progress.set_trade_progress,
-        "Unlock the Equip Menu": other.unlock_equip_menu.unlock_equip,
-        "Get Gold Pass": other.get_gold_pass.get_gold_pass,
+        "Get / Remove Gold Pass": other.get_gold_pass.get_gold_pass,
         "Claim / Remove all user rank rewards (does not give any items)": other.claim_user_rank_rewards.edit_rewards,
+        "Cat Shrine Level / XP": other.cat_shrine.edit_shrine_xp,
     },
-    "Edit Config" : {
-        "Edit DEFAULT_GAME_VERSION" : config_manager.edit_default_gv,
-        "Edit DEFAULT_SAVE_PATH" : config_manager.edit_default_save_file_path,
-        "Edit EDITOR settings" : config_manager.edit_editor_settings,
-        "Edit START_UP settings" : config_manager.edit_start_up_settings,
-        "Edit SAVE_CHANGES settings" : config_manager.edit_save_changes_settings,
-        "Edit SERVER settings" : config_manager.edit_server_settings,
-    }
-} 
+    "Fixes": {
+        "Fix time errors" : other.fix_time_issues.fix_time_issues,
+        "Unlock the Equip Menu": other.unlock_equip_menu.unlock_equip,
+        "Clear Tutorial": levels.clear_tutorial.clear_tutorial,
+        "Fix elsewhere error / Unban account": other.fix_elsewhere.fix_elsewhere,
+        "Old Fix elsewhere error / Unban account (needs 2 save files)": fix_elsewhere_old,
+        "Fix gamatoto from crashing the game": gamototo.fix_gamatoto.fix_gamatoto,
+    },
+    "Edit Config": {
+        "Edit DEFAULT_COUNTRY_CODE": config_manager.edit_default_gv,
+        "Edit DEFAULT_SAVE_PATH": config_manager.edit_default_save_file_path,
+        "Edit FIXED_SAVE_PATH": config_manager.edit_fixed_save_path,
+        "Edit EDITOR settings": config_manager.edit_editor_settings,
+        "Edit START_UP settings": config_manager.edit_start_up_settings,
+        "Edit SAVE_CHANGES settings": config_manager.edit_save_changes_settings,
+        "Edit SERVER settings": config_manager.edit_server_settings,
+        "Edit config path": config_manager.edit_config_path,
+    },
+    "Exit": helper.exit_check_changes,
+}
 
 
 def get_feature(
