@@ -1,12 +1,13 @@
 """Helper script for usefull functions"""
 
+import filecmp
 import json
 from multiprocessing import Process
 import os
 import shutil
 import sys
-from tkinter import Tk, filedialog
-from typing import Any, Generator, Optional, Union
+import time
+from typing import Any, Callable, Generator, Optional, Union
 import colored  # type: ignore
 
 from . import (
@@ -27,6 +28,18 @@ WHITE = "#FFFFFF"
 CYAN = "#00FFFF"
 
 
+def get_time() -> int:
+    """Get current time in seconds"""
+
+    return int(time.time())
+
+
+def get_iso_time() -> str:
+    """Get the current time in iso format"""
+
+    return time.strftime("%Y-%m-%dT%H:%M:%S", time.localtime())
+
+
 def print_line_seperator(base: str, char: str = "-", length: int = 80):
     """Print a line of a char"""
     width = shutil.get_terminal_size().columns
@@ -87,6 +100,17 @@ def get_file(file_name: str) -> str:
     return file_path
 
 
+def get_files_in_dir(dir_path: str) -> list[str]:
+    """Get all files in a directory"""
+
+    files: list[str] = []
+    for file in os.listdir(dir_path):
+        if os.path.isfile(os.path.join(dir_path, file)):
+            file_path = os.path.join(dir_path, file)
+            files.append(file_path)
+    return files
+
+
 def find_files_in_dir(dir_path: str, file_name: str) -> list[str]:
     """Find all files in a directory with a certain name"""
 
@@ -126,12 +150,26 @@ def chunks(lst: list[Any], chunk_len: int) -> Generator[Any, Any, Any]:
 def frames_to_time(frames: int) -> dict[str, Any]:
     """Turn frames into hours, minutes, seconds, frames"""
 
+    frames = clamp_int(frames)
     seconds, frames = divmod(frames, 30)
     minutes, seconds = divmod(seconds, 60)
     hours, minutes = divmod(minutes, 60)
     return {"hh": hours, "mm": minutes, "ss": seconds, "frames": frames}
 
 
+def clamp_int(value: int) -> int:
+    """
+    Clamp an integer to the range of a signed 32 bit integer
+
+    Args:
+        value (int): The value to clamp
+
+    Returns:
+        int: The clamped value
+    """
+    return clamp(value, 0, (2**31) - 1)
+
+
 def num_to_bytes(num: int, length: int) -> bytes:
     """Turn number into little endian bytes"""
 
@@ -161,6 +199,7 @@ def time_to_frames(time: dict[str, Any]) -> int:
     total_frames += time["ss"] * 30
     total_frames += time["mm"] * 60 * 30
     total_frames += time["hh"] * 60 * 60 * 30
+    total_frames = clamp_int(total_frames)
     return total_frames
 
 
@@ -224,7 +263,7 @@ def get_save_path() -> str:
 def set_save_path(path: str) -> None:
     """Set the save path in the env variable"""
 
-    os.environ["BC_SAVE_PATH"] = path
+    os.environ["BC_SAVE_PATH"] = os.path.abspath(path)
 
 
 def get_text_splitter(isjp: bool):
@@ -374,33 +413,90 @@ def check_tracker(save_stats: dict[str, Any], path: str) -> None:
             colored_text("Uploaded meta data", new=GREEN)
 
 
-def ask_exit_editor():
-    """Exit the editor"""
-
-    is_exit = (
-        user_input_handler.colored_input("Do you want to exit the editor? (&y&/&n&):")
-        == "y"
-    )
-    if is_exit:
-        exit_editor()
-
-
 def exit_editor():
     """Exit the editor"""
 
     sys.exit(0)
 
 
+def check_changes(_: Any):
+    """
+    Check if the user wants to exit the editor
+
+    Args:
+        _ (Any): Unused
+    """
+    save_path = get_save_path()
+    temp_file_path = os.path.join(
+        config_manager.get_app_data_folder(), "SAVE_DATA_temp"
+    )
+    if not os.path.exists(temp_file_path):
+        return
+    is_identical = are_identical_files(save_path, temp_file_path)
+    if is_identical:
+        return
+
+    ask_save_changes()
+
+
+def exit_check_changes(_: Any = None):
+    check_changes(None)
+    exit_editor()
+
+
+def ask_save_changes():
+    """
+    Ask if the user wants to save the changes
+    """
+    save = (
+        user_input_handler.colored_input(
+            "You have unsaved changes. Would you like to save them? (&y&/&n&):"
+        )
+        == "y"
+    )
+    if save:
+        current_path = get_save_path()
+        temp_file_path = os.path.join(
+            config_manager.get_app_data_folder(), "SAVE_DATA_temp"
+        )
+        if os.path.exists(temp_file_path):
+            data = read_file_bytes(temp_file_path)
+            save_stats = parse_save.start_parse(data, get_country_code(data))
+            check_tracker(save_stats, temp_file_path)
+            write_file_bytes(current_path, read_file_bytes(temp_file_path))
+            colored_text(
+                f"Save data saved to &{current_path}&",
+                base=GREEN,
+                new=WHITE,
+            )
+
+
+def are_identical_files(file1: str, file2: str) -> bool:
+    """Check if two files are identical"""
+
+    return filecmp.cmp(file1, file2)
+
+
 def check_cat_ids(cat_ids: list[int], save_stats: dict[str, Any]) -> list[int]:
     """Check if a list of cat ids is valid"""
-
+    new_cat_ids: list[int] = []
     for cat_id in cat_ids:
-        if cat_id > len(save_stats["cats"]):
+        if cat_id > len(save_stats["cats"]) - 1:
             colored_text(f"Invalid cat id {cat_id}", base=RED)
-            cat_ids.remove(cat_id)
-    return cat_ids
+            continue
+        new_cat_ids.append(cat_id)
+    return new_cat_ids
 
 
+def error_text(text: str):
+    """Print error text"""
+
+    colored_text(text, base=RED)
+
+def is_android() -> bool:
+    """Check if the user is on android"""
+    return "ANDROID_ROOT" in os.environ
+
 def colored_text(
     text: str,
     base: str = WHITE,
@@ -461,7 +557,7 @@ def colored_list(
         final += f"&{item}&"
         if extra_data:
             if extra_data[i] is not None:
-                if isinstance(offset, int):
+                if isinstance(offset, int) and isinstance(extra_data[i], int):
                     final += f" &:& {extra_data[i]+offset}"
                 else:
                     final += f" &:& {extra_data[i]}"
@@ -474,7 +570,9 @@ def calculate_user_rank(save_stats: dict[str, Any]):
     """Calculate the user rank"""
 
     user_rank = 10  # blue upgrade base level (1 each)
-    user_rank += sum(save_stats["cats"])
+    for cat_flag in save_stats["cats"]:
+        if cat_flag == 1:
+            user_rank += 1
     user_rank += sum(save_stats["cat_upgrades"]["Base"])
     user_rank += sum(save_stats["cat_upgrades"]["Plus"])
     user_rank += sum(save_stats["blue_upgrades"]["Base"])
@@ -508,18 +606,37 @@ def select_dir(title: str, default_dir: str) -> str:
     Returns:
         str: Selected directory
     """
+    if not has_tkinter():
+        return default_dir
+    from tkinter import filedialog  # type: ignore
+
     root = setup_tk()
     dir_path = filedialog.askdirectory(title=title, initialdir=default_dir, parent=root)
     return dir_path
 
 
-def setup_tk() -> Tk:
+def has_tkinter() -> bool:
+    """Check if tkinter is installed"""
+    try:
+        import tkinter  # type: ignore
+    except ImportError:
+        return False
+    try:
+        setup_tk()
+    except tkinter.TclError:
+        return False
+    return True
+
+
+def setup_tk() -> Any:
     """
     Setup the tkinter window
 
     Returns:
         Tk: Tkinter window
     """
+    from tkinter import Tk
+
     root = Tk()
     root.withdraw()
     root.wm_attributes("-topmost", 1)  # type: ignore
@@ -541,6 +658,16 @@ def run_in_parallel(fns: list[Process]) -> None:
         p.join()
 
 
+def run_in_background(func: Callable[..., Any]) -> None:
+    """
+    Run a function in the background
+
+    Args:
+        fn (Callable[..., Any]): Function to run in the background
+    """
+    Process(target=func).start()
+
+
 def get_cc(save_stats: dict[str, Any]) -> str:
     """Get the country code"""
 
@@ -548,12 +675,37 @@ def get_cc(save_stats: dict[str, Any]) -> str:
         return "jp"
     return "en"
 
+def get_lang(jp: bool) -> str:
+    """Get the language code"""
+
+    if jp:
+        return "ja"
+    return "en"
+
+
+def get_save_path_home() -> str:
+    """
+    Get the save path
+
+    Returns:
+        str: Save path
+    """
+    save_name = get_default_save_name()
+    if config_manager.get_config_value("FIXED_SAVE_PATH"):
+        path = os.path.join(get_home_path(), "bc_saves", os.path.basename(save_name))
+        create_dirs(os.path.dirname(path))
+        return path
+    return save_name
+
 
 def save_file(
     title: str, file_types: list[tuple[str, str]], path: str
 ) -> Optional[str]:
     """Save a file with tkinter"""
+    if not has_tkinter():
+        return path
     setup_tk()
+    from tkinter import filedialog
 
     try:
         path_d = filedialog.asksaveasfile(
@@ -582,7 +734,17 @@ def select_file(
     initial_file: str = "",
 ) -> str:
     """Select a file with tkinter"""
+    if not has_tkinter():
+        path = user_input_handler.colored_input(
+            f"Enter the path to the file ({title}): "
+        )
+        if not os.path.isfile(path):
+            colored_text("Invalid path", new=RED)
+            return ""
+        return path
     setup_tk()
+    from tkinter import filedialog
+
     file_path = filedialog.askopenfilename(
         initialdir=default_dir,
         title=title,
@@ -592,6 +754,16 @@ def select_file(
     return file_path
 
 
+def get_home_path() -> str:
+    """
+    Get the home path
+
+    Returns:
+        str: Home path
+    """
+    return os.path.expanduser("~")
+
+
 def get_default_save_name() -> str:
     """
     Get the default save name
@@ -636,13 +808,14 @@ def get_country_code(save_data: bytes) -> str:
 
 def ask_cc():
     """Ask the user for their country code"""
-    default_gv = config_manager.get_config_value("DEFAULT_GAME_VERSION")
+    default_gv = config_manager.get_config_value("DEFAULT_COUNTRY_CODE")
     if default_gv:
-        colored_text(f"Using default game version: &{default_gv}&")
-        return default_gv
+        if len(default_gv) == 2:
+            colored_text(f"Using default country code: &{default_gv}&")
+            return default_gv
 
     country_code = user_input_handler.colored_input(
-        "Enter your game version (&en&, &jp&, &kr&, &tw&):"
+        "Enter your country code (&en&, &jp&, &kr&, &tw&):"
     )
     return country_code
 
@@ -652,7 +825,7 @@ def export_json(save_stats: dict[str, Any], path: str) -> None:
 
     ordered_data = parse_save.re_order(save_stats)
     if os.path.isdir(path):
-        path = os.path.join(path, f"{get_default_save_name()}.json")
+        path = os.path.join(path, f"{get_save_path_home()}.json")
     write_file_string(path, json.dumps(ordered_data, indent=4))
     colored_text(f"Successfully wrote json to &{os.path.abspath(path)}&")
 
@@ -666,7 +839,7 @@ def load_json_handler(json_path: str) -> Union[None, str]:
     path = save_file(
         "Save file",
         get_save_file_filetype(),
-        os.path.join(os.path.dirname(json_path), get_default_save_name()),
+        os.path.join(os.path.dirname(json_path), get_save_path_home()),
     )
     if path is None:
         return None
