@@ -212,33 +212,45 @@ def get_utf8_string(length: Union[int, None] = None) -> str:
     return data
 
 
-def get_some_data():
-    skip(80)
-    # unknown
-    skip(9)
-    skip(40)
-    skip(41)
-    skip(35)
-    # unknown
-    skip(80)
-    skip(9)
-    skip(40)
-    skip(41)
-    skip(35)
-    print(address)
+def read_variable_length_int() -> int:
+    """
+    Read a variable length int from the save file
+
+    Returns:
+        int: The value of the variable length int
+    """
+    i = 0
+    for _ in range(4):
+        i_3 = i << 7
+        read = next_int(1)
+        i = i_3 | (read & 127)
+        if (read & 128) == 0:
+            return i
+    return i
 
 
-def skip_some_data(save_data: bytes, total_cats: int) -> dict[str, int]:
-    pos = save_data.find(total_cats.to_bytes(4, "little"), address)
-    pos_2 = save_data.find(total_cats.to_bytes(4, "little"), pos + 1)
-    pos_3 = save_data.find(total_cats.to_bytes(4, "little"), pos_2 + 1)
-    if max(pos, pos_2, pos_3) - min(pos, pos_2, pos_3) < 20:
-        pos = max(pos, pos_2, pos_3)
-    if pos > address:
-        pos -= 24
+def load_bonus_hash() -> tuple[dict[int, int], dict[int, int]]:
+    """
+    Get the variable data from the save file
 
-    length = pos - address
-    return {"Value": next_int(length), "Length": length}
+    Returns:
+        tuple[dict[int, int], dict[int, int]]: The variable data
+    """
+    length_1 = read_variable_length_int()
+    data_1: dict[int, int] = {}
+    for _ in range(length_1):
+        key = read_variable_length_int()
+        val = read_variable_length_int()
+        data_1[key] = val
+
+    length_2 = read_variable_length_int()
+    data_2: dict[int, int] = {}
+    for _ in range(length_2):
+        key = read_variable_length_int()
+        val = next_int(1)
+        data_2[key] = val
+
+    return (data_1, data_2)
 
 
 def get_event_stages_current() -> dict[str, Any]:
@@ -631,94 +643,18 @@ def get_mission_segment() -> dict[int, int]:
         missions[mission_id] = mission_value
     return missions
 
-
 def get_mission_data() -> dict[str, Any]:
     missions: dict[str, dict[int, int]] = {}
-    missions[
-        "flags"
-    ] = (
-        get_mission_segment()
-    )  # 4 = claimed, 3 = unlocked, 2 = completed 0/1 = not unlocked
-    missions[
-        "values"
-    ] = get_mission_segment()  # e.g number of gamatoto expeditions, stages cleared etc
+    missions["states"] = get_mission_segment()
+    missions["requirements"] = get_mission_segment()
+    missions["clear_types"] = get_mission_segment()
+    missions["gamatoto"] = get_mission_segment()
+    missions["nyancombo"] = get_mission_segment()
+    missions["user_rank"] = get_mission_segment()
+    missions["expiry"] = get_mission_segment()
+    missions["preparing"] = get_mission_segment()
     return missions
 
-
-def get_looped_data() -> list[dict[str, int]]:
-    data: list[dict[str, int]] = []
-    val_114 = next_int_len(4)
-    data.append(val_114)
-
-    val_118 = next_int_len(4)
-    data.append(val_118)
-
-    for _ in range(val_114["Value"]):
-        val_22 = next_int_len(4)
-        data.append(val_22)
-
-        val_118 = next_int_len(4)
-        data.append(val_118)
-
-    val_114 = next_int_len(4)
-    data.append(val_114)
-    for _ in range(val_118["Value"]):
-        val_22 = next_int_len(4)
-        data.append(val_22)
-
-        val_114 = next_int_len(4)
-        data.append(val_114)
-
-    val_118 = next_int_len(4)
-    data.append(val_118)
-
-    for _ in range(val_114["Value"]):
-        val_22 = next_int_len(4)
-        data.append(val_22)
-
-        val_118 = next_int_len(4)
-        data.append(val_118)
-
-    val_114 = next_int_len(4)
-    data.append(val_114)
-    for _ in range(val_118["Value"]):
-        val_22 = next_int_len(4)
-        data.append(val_22)
-
-        val_114 = next_int_len(4)
-        data.append(val_114)
-
-    val_118 = next_int_len(4)
-    data.append(val_118)
-
-    for _ in range(val_114["Value"]):
-        val_22 = next_int_len(4)
-        data.append(val_22)
-
-        val_118 = next_int_len(4)
-        data.append(val_118)
-
-    val_54 = next_int_len(4)
-    data.append(val_54)
-
-    for _ in range(val_118["Value"]):
-        val_24 = next_int_len(4)
-        data.append(val_24)
-
-        val_54 = next_int_len(4)
-        data.append(val_54)
-
-    val_61 = next_int_len(4)
-    data.append(val_61)
-
-    for _ in range(val_54["Value"]):
-        for _ in range(val_61["Value"]):
-            val_15 = next_int_len(1)
-            data.append(val_15)
-
-    return data
-
-
 def get_data_after_challenge() -> list[dict[str, int]]:
     data: list[dict[str, int]] = []
     gv_67 = next_int_len(4)  # 0x43
@@ -939,7 +875,7 @@ def get_gold_pass_data() -> dict[str, Any]:
 
     data: dict[str, Any] = {}
     data["officer_id"] = next_int_len(4)
-    data["flag"] = next_int_len(4)
+    data["renewal_times"] = next_int_len(4)
     data["start_date"] = get_double()
     data["expiry_date"] = get_double()
     data["unknown_2"] = get_length_doubles(length=2)
@@ -949,24 +885,22 @@ def get_gold_pass_data() -> dict[str, Any]:
     data["flag_2"] = next_int_len(4)
     data["expiry_date_3"] = get_double()
 
+    number_of_rewards = next_int(4)
+    claimed_rewards: dict[int, int] = {}
+    for _ in range(number_of_rewards):
+        item_id = next_int(4)
+        amount = next_int(4)
+        claimed_rewards[item_id] = amount
+
+    data["claimed_rewards"] = claimed_rewards
+    data["unknown_4"] = next_int_len(8)
+    data["unknown_5"] = next_int_len(1)
+    data["unknown_6"] = next_int_len(1)
+
     return data
 
 
-def get_talent_data() -> dict[str, Any]:
-    data: list[dict[str, int]] = []
-
-    val_4 = next_int_len(4)
-    data.append(val_4)
-    for _ in range(val_4["Value"]):
-        val_7 = next_int_len(4)
-        data.append(val_7)
-        val_3 = next_int_len(4)
-        data.append(val_3)
-
-    data.append(next_int_len(8))
-    data.append(next_int_len(1))
-    data.append(next_int_len(1))
-
+def get_talent_data() -> dict[int, list[dict[str, int]]]:
     total_cats = next_int(4)
 
     talents: dict[int, list[dict[str, int]]] = {}
@@ -982,7 +916,7 @@ def get_talent_data() -> dict[str, Any]:
             talent = {"id": talent_id, "level": talent_level}
             cat_data.append(talent)
         talents[cat_id] = cat_data
-    return {"talents": talents, "dump": data}
+    return talents
 
 
 def get_medals() -> dict[str, Any]:
@@ -1082,49 +1016,67 @@ def get_data_after_after_leadership(dst: bool) -> list[dict[str, int]]:
         data.append(next_int_len(7))
     return data
 
+def get_legend_quest_current() -> dict[str, Any]:
+    total_subchapters = next_int(1)
+    stages_per_subchapter = next_int(1)
+    stars = next_int(1)
+
+    clear_progress = get_length_data(4, 1, total_subchapters * stars)
+    clear_progress = list(helper.chunks(clear_progress, stars))
+
+    return {
+        "Clear": clear_progress,
+        "total": total_subchapters,
+        "stages": stages_per_subchapter,
+        "stars": stars,
+    }
+
+def get_legend_quest_progress(lengths: dict[str, Any]):
+    total = lengths["total"]
+    stars = lengths["stars"]
+    stages = lengths["stages"]
+
+    clear_progress = get_length_data(4, 1, total * stars)
+    clear_progress = list(helper.chunks(clear_progress, stars))
+    clear_amount = get_length_data(4, 2, total * stars * stages)
+    tries = get_length_data(4, 2, total * stars * stages)
+
+    unlock_next = get_length_data(4, 1, total * stars)
+    unlock_next = list(helper.chunks(unlock_next, stars))
+
+    clear_amount = list(helper.chunks(clear_amount, stages * stars))
+    tries = list(helper.chunks(tries, stages * stars))
+
+    clear_amount_sep: list[list[list[int]]] = []
+    stage_ids_sep: list[list[list[int]]] = []
+
+    for clear_amount_val in clear_amount:
+        sub_chapter_clears: list[list[int]] = []
+        for j in range(stars):
+            sub_chapter_clears.append(clear_amount_val[j::stars])
+        clear_amount_sep.append(sub_chapter_clears)
+    clear_amount = clear_amount_sep
+
+    for stage_id_val in tries:
+        sub_chapter_ids: list[list[int]] = []
+        for j in range(stars):
+            sub_chapter_ids.append(stage_id_val[j::stars])
+        stage_ids_sep.append(sub_chapter_ids)
+    tries = stage_ids_sep
+
+    return {
+        "Value": {
+            "clear_progress": clear_progress,
+            "clear_amount": clear_amount,
+            "tries": tries,
+            "unlock_next": unlock_next,
+        },
+        "Lengths": lengths,
+    }
+
 
 def get_data_after_leadership() -> list[dict[str, int]]:
     data: list[dict[str, int]] = []
-    val_16 = next_int_len(1)
-    data.append(val_16)
-
-    val_45 = next_int_len(1)
-    data.append(val_45)
-
-    val_18 = next_int_len(1)
-    data.append(val_18)
-
-    for _ in range(val_16["Value"]):
-        for _ in range(val_18["Value"]):
-            val_15 = next_int_len(1)
-            data.append(val_15)
-
-    for _ in range(val_16["Value"]):
-        for _ in range(val_18["Value"]):
-            val_15 = next_int_len(1)
-            data.append(val_15)
-
-    for _ in range(val_16["Value"]):
-        for _ in range(val_45["Value"]):
-            for _ in range(val_18["Value"]):
-                val_20 = next_int_len(2)
-                data.append(val_20)
-
-    for _ in range(val_16["Value"]):
-        for _ in range(val_45["Value"]):
-            for _ in range(val_18["Value"]):
-                val_20 = next_int_len(2)
-                data.append(val_20)
-
-    for _ in range(val_16["Value"]):
-        for _ in range(val_18["Value"]):
-            val_15 = next_int_len(1)
-            data.append(val_15)
-
-    for _ in range(val_16["Value"]):
-        data.append(next_int_len(1))
-    for _ in range(48):
-        data.append(next_int_len(4))
 
     data.append(next_int_len(2))
     data.append(next_int_len(1))
@@ -1206,6 +1158,178 @@ def get_gauntlet_progress(
     }
 
 
+class ClearedSlots:
+    class Slot:
+        class Cat:
+            def __init__(self, cat_id: int, cat_form: int):
+                self.cat_id = cat_id
+                self.cat_form = cat_form
+
+            def to_dict(self) -> dict[str, Any]:
+                return {
+                    "cat_id": self.cat_id,
+                    "cat_form": self.cat_form,
+                }
+
+            @staticmethod
+            def from_dict(data: dict[str, Any]) -> "ClearedSlots.Slot.Cat":
+                return ClearedSlots.Slot.Cat(data["cat_id"], data["cat_form"])
+
+        def __init__(self, cats: list[Cat], slot_index: int, separator: int):
+            self.cats = cats
+            self.slot_index = slot_index
+            self.separator = separator
+
+        def to_dict(self) -> dict[str, Any]:
+            return {
+                "cats": [cat.to_dict() for cat in self.cats],
+                "slot_index": self.slot_index,
+                "separator": self.separator,
+            }
+
+        @staticmethod
+        def from_dict(data: dict[str, Any]):
+            return ClearedSlots.Slot(
+                [ClearedSlots.Slot.Cat.from_dict(cat) for cat in data["cats"]],
+                data["slot_index"],
+                data["separator"],
+            )
+
+    class StageSlot:
+        class Stage:
+            def __init__(self, stage_id: int):
+                self.stage_id = stage_id
+
+            def to_dict(self) -> dict[str, Any]:
+                return {
+                    "stage_id": self.stage_id,
+                }
+
+            @staticmethod
+            def from_dict(data: dict[str, Any]) -> "ClearedSlots.StageSlot.Stage":
+                return ClearedSlots.StageSlot.Stage(data["stage_id"])
+
+        def __init__(self, slot_index: int, stages: list[Stage]):
+            self.slot_index = slot_index
+            self.stages = stages
+
+        def to_dict(self) -> dict[str, Any]:
+            return {
+                "slot_index": self.slot_index,
+                "stages": [stage.to_dict() for stage in self.stages],
+            }
+
+        @staticmethod
+        def from_dict(data: dict[str, Any]) -> "ClearedSlots.StageSlot":
+            return ClearedSlots.StageSlot(
+                data["slot_index"],
+                [
+                    ClearedSlots.StageSlot.Stage.from_dict(stage)
+                    for stage in data["stages"]
+                ],
+            )
+
+    def __init__(self, slots: list[Slot], slot_stages: list[StageSlot], end_index: int):
+        self.slots = slots
+        self.slot_stages = slot_stages
+        self.end_index = end_index
+
+    def to_dict(self) -> dict[str, Any]:
+        return {
+            "slots": [slot.to_dict() for slot in self.slots],
+            "slot_stages": [stage.to_dict() for stage in self.slot_stages],
+            "end_index": self.end_index,
+        }
+
+    @staticmethod
+    def from_dict(data: dict[str, Any]) -> "ClearedSlots":
+        return ClearedSlots(
+            [ClearedSlots.Slot.from_dict(slot) for slot in data["slots"]],
+            [ClearedSlots.StageSlot.from_dict(stage) for stage in data["slot_stages"]],
+            data["end_index"],
+        )
+
+
+def get_enigma_stages() -> dict[str, Any]:
+    """
+    Gets the enigma stages
+
+    Returns:
+        dict[str, Any]: The enigma stages
+    """
+    enigma_data: dict[str, Any] = {}
+    enigma_data["energy_since_1"] = next_int(4)
+    enigma_data["energy_since_2"] = next_int(4)
+    enigma_data["enigma_level"] = next_int(1)
+    enigma_data["unknown_2"] = next_int(1)
+    enigma_data["unknown_3"] = next_int(1)
+
+    total_stages = next_int(1)
+    stages: list[dict[str, Any]] = []
+    for _ in range(total_stages):
+        data = {}
+        data["level"] = next_int(4)  # 0 = inferior, 1 = normal, 2 = superior
+        data["stage_id"] = next_int(4)
+        data["decoding_status"] = next_int(
+            1
+        )  # 0 = not decoded, 1 = decoded, 2 = revealed
+        data["start_time"] = get_double()
+        stages.append(data)
+    enigma_data["stages"] = stages
+    return enigma_data
+
+
+def get_cleared_slots() -> tuple[dict[str, Any], list[dict[str, int]]]:
+    """
+    Returns the line ups of the cleared stages
+
+    Returns:
+        dict[str, Any]: The line ups of the cleared stages
+    """
+    total_slots = next_int(2)
+    index = next_int(2)
+    slots: list[ClearedSlots.Slot] = []
+
+    for _ in range(total_slots):
+        cats: list[ClearedSlots.Slot.Cat] = []
+        for _ in range(10):
+            cat_id = next_int(2)
+            cat_form = next_int(1)
+            cat_data = ClearedSlots.Slot.Cat(cat_id, cat_form)
+            cats.append(cat_data)
+        separator = next_int(3)
+        slot = ClearedSlots.Slot(cats, index, separator)
+        index = next_int(2)
+        slots.append(slot)
+
+    cleared_slot_data: list[ClearedSlots.StageSlot] = []
+    index_2 = next_int(2)
+    for _ in range(index):
+        total_stages = next_int(2)
+        stages: list[ClearedSlots.StageSlot.Stage] = []
+        for _ in range(total_stages):
+            stage_id = next_int(4)
+            stage = ClearedSlots.StageSlot.Stage(stage_id)
+            stages.append(stage)
+        stages_data = ClearedSlots.StageSlot(index_2, stages)
+        index_2 = next_int(2)
+        cleared_slot_data.append(stages_data)
+
+    data_2: list[dict[str, int]] = []
+    data_2.append({"Value": index_2, "Length": 2})
+    for _ in range(index_2):
+        val_18 = next_int_len(2)
+        data_2.append(val_18)
+
+        val_4 = next_int_len(1)
+        data_2.append(val_4)
+    data_2.append(next_int_len(4))  # 90400
+
+    cleared_slots = ClearedSlots(slots, cleared_slot_data, index)
+
+    return cleared_slots.to_dict(), data_2
+
+
 def get_data_after_gauntlets() -> list[dict[str, int]]:
     data: list[dict[str, int]] = []
 
@@ -1220,40 +1344,6 @@ def get_data_after_gauntlets() -> list[dict[str, int]]:
         data.append(next_int_len(1))
         data.append(next_int_len(8))
 
-    val_20 = next_int_len(2)
-    data.append(val_20)
-
-    val_18 = next_int_len(2)
-    data.append(val_18)
-
-    for _ in range(val_20["Value"]):
-        data.append(next_int_len((2 + 1) * 10))
-        data.append(next_int_len(3))
-        val_18 = next_int_len(2)
-        data.append(val_18)
-
-    val_20 = next_int_len(2)
-    data.append(val_20)
-
-    for _ in range(val_18["Value"]):
-        val_30 = next_int_len(2)
-        data.append(val_30)
-
-        for _ in range(val_30["Value"]):
-            val_33 = next_int_len(4)
-            data.append(val_33)
-
-        val_20 = next_int_len(2)
-        data.append(val_20)
-
-    for _ in range(val_20["Value"]):
-        val_18 = next_int_len(2)
-        data.append(val_18)
-
-        val_4 = next_int_len(1)
-        data.append(val_4)
-
-    data.append(next_int_len(4))  # 90400
     return data
 
 
@@ -1286,19 +1376,30 @@ def get_data_after_orbs() -> list[dict[str, int]]:
     data.append(next_int_len(4))  # 90800
 
     data.append(next_int_len(1))
-    data.append(next_int_len(8 * 2))
-    data.append(next_int_len(1))
-
-    length = next_int_len(1)
-    data.append(length)
-    for _ in range(length["Value"]):
-        data.append(next_int_len(1))
-
-    data.append(next_int_len(8 * 3))
-    data.append(next_int_len(4))  # 90900
     return data
 
 
+def get_cat_shrine_data() -> dict[str, Any]:
+    """
+    Gets the cat shrine data
+
+    Returns:
+        dict[str, Any]: The cat shrine data
+    """
+    stamp_1 = get_double()
+    stamp_2 = get_double()
+    shrine_gone = next_int(1)
+    flags: list[int] = get_length_data(1, 1)
+    xp_offering = next_int(4)
+    return {
+        "flags": flags,
+        "xp_offering": xp_offering,
+        "shrine_gone": shrine_gone,
+        "stamp_1": stamp_1,
+        "stamp_2": stamp_2,
+    }
+
+
 def get_slot_names(save_stats: dict[str, Any]) -> list[str]:
     total_slots = len(save_stats["slots"])
     if save_stats["game_version"]["Value"] >= 110600:
@@ -1465,6 +1566,7 @@ def check_gv(save_stats: dict[str, Any], game_version: int) -> dict[str, Any]:
     if save_stats["game_version"]["Value"] < game_version:
         save_stats = exit_parser(save_stats)
         save_stats["exit"] = True
+        save_stats["extra_data"] = next_int_len(0)
     else:
         save_stats["exit"] = False
     return save_stats
@@ -1540,6 +1642,89 @@ def get_double() -> float:
     return val
 
 
+def get_110800_data() -> list[dict[str, int]]:
+    """
+    Get the data from 11.7.0
+
+    Returns:
+        list[dict[str, int]]: The data
+    """
+    data: list[dict[str, int]] = []
+
+    u_var_38 = next_int_len(1)
+    data.append(u_var_38)
+
+    return data
+
+
+def get_110800_data_2() -> list[dict[str, int]]:
+    """
+    Get the data from 11.7.0
+
+    Returns:
+        list[dict[str, int]]: The data
+    """
+    data: list[dict[str, int]] = []
+
+    u_var_38 = next_int_len(1)
+    data.append(u_var_38)
+
+    u_var_38 = next_int_len(1)
+    data.append(u_var_38)
+
+    return data
+
+
+def get_110700_data() -> list[dict[str, int]]:
+    """
+    Get the data from 110600
+
+    Returns:
+        list[dict[str, int]]: The data
+    """
+    data: list[dict[str, int]] = []
+
+    i_var_32 = next_int_len(4)
+    data.append(i_var_32)
+
+    for _ in range(i_var_32["Value"]):
+        pi_var_33 = next_int_len(4)
+        data.append(pi_var_33)
+
+        f_var_54 = next_int_len(8)
+        data.append(f_var_54)
+
+        f_var_54 = next_int_len(8)
+        data.append(f_var_54)
+
+    return data
+
+
+def get_login_bonuses() -> dict[int, int]:
+    """
+    Get the login bonuses
+
+    Returns:
+        dict[int, int]: The login bonuses
+    """
+    length = next_int(4)
+    data: dict[int, int] = {}
+    for _ in range(length):
+        login_id = next_int(4)
+        data[login_id] = next_int(4)
+    return data
+
+def get_tower_item_obtained() -> list[list[int]]:
+    total_stars = next_int(4)
+    total_stages = next_int(4)
+    data: list[list[int]] = []
+    for _ in range(total_stars):
+        star_data: list[int] = []
+        for _ in range(total_stages):
+            star_data.append(next_int(1))
+        data.append(star_data)
+    return data
+
 def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, Any]:
     """Parse the save data."""
 
@@ -1554,8 +1739,8 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
 
     save_stats["unknown_1"] = next_int_len(1)
 
-    save_stats["sound_effects"] = next_int_len(1)
-    save_stats["music"] = next_int_len(1)
+    save_stats["mute_music"] = next_int_len(1)
+    save_stats["mute_sound_effects"] = next_int_len(1)
 
     save_stats["cat_food"] = next_int_len(4)
     save_stats["current_energy"] = next_int_len(4)
@@ -1617,7 +1802,7 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
     save_stats["unknown_9"] = next_int_len(6 * 4)
 
     save_stats["thirty2_code"] = get_utf8_string()
-    save_stats["unknown_10"] = skip_some_data(save_data, len(save_stats["cats"]))
+    save_stats["unknown_10"] = load_bonus_hash()
     save_stats["unknown_11"] = get_length_data(length=4)
     save_stats["normal_tickets"] = next_int_len(4)
     save_stats["rare_tickets"] = next_int_len(4)
@@ -1650,8 +1835,7 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
 
     save_stats["fourth_time"] = get_time_data(save_stats["dst"])
     save_stats["unknown_105"] = get_length_data(length=5)
-    save_stats["unknown_108"] = {}
-    save_stats["unknown_107"] = next_int_len(3)
+    save_stats["unknown_107"] = get_length_data(separator=1, length=3)
 
     if save_stats["dst"]:
         save_stats["unknown_110"] = get_utf8_string()
@@ -1693,7 +1877,7 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
     else:
         save_stats["unknown_24"] = next_int_len(4)
 
-    save_stats["catseye_related_data"] = get_length_data()
+    save_stats["catseye_related_data"] = get_cat_upgrades()
     save_stats["unknown_22"] = get_length_data(length=11)
     save_stats["user_rank_rewards"] = get_length_data(4, 1)
 
@@ -1725,9 +1909,10 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
 
     save_stats["unknown_25"] = next_int_len(1)
 
-    save_stats["check_ban_state_succeeded"] = next_int_len(4)
+    save_stats["backup_state"] = next_int_len(4)
 
-    save_stats["unknown_119"] = next_int_len(1)
+    if save_stats["dst"]:
+        save_stats["unknown_119"] = next_int_len(1)
 
     save_stats["gv_44"] = next_int_len(4)
 
@@ -1737,10 +1922,7 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
         helper.chunks(get_length_data(4, 4, 51 * 3), 51)
     )
 
-    if save_stats["dst"]:
-        save_stats["unknown_27"] = next_int_len(4)
-    else:
-        save_stats["unknown_27"] = next_int_len(3)
+    save_stats["unknown_27"] = next_int_len(4)
     save_stats["cat_related_data_1"] = get_length_data()
     save_stats["unknown_28"] = next_int_len(1)
 
@@ -1805,10 +1987,13 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
     save_stats["gamatoto_skin"] = next_int_len(4)
     save_stats["platinum_tickets"] = next_int_len(4)
 
-    save_stats["unknown_48"] = get_length_data(4, 8)
+    save_stats["login_bonuses"] = get_login_bonuses()
     save_stats["unknown_49"] = next_int_len(16)
-    save_stats["unknown_50"] = get_length_data(length=36)
+    save_stats["announcment"] = get_length_data(length=32)
 
+    save_stats["backup_counter"] = next_int_len(4)
+
+    save_stats["unknown_131"] = get_length_data(length=3)
     save_stats["gv_55"] = next_int_len(4)
 
     save_stats["unknown_51"] = next_int_len(1)
@@ -1816,27 +2001,29 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
     save_stats["unknown_113"] = get_data_before_outbreaks()
 
     save_stats["dojo_data"] = get_dojo_data_maybe()
+    save_stats["dojo_item_lock"] = next_int_len(1)
+    save_stats["dojo_locks"] = get_length_data(1, 1, 2)
 
-    save_stats["unknown_114"] = next_int_len(7)
+    save_stats["unknown_114"] = next_int_len(4)
     save_stats["gv_58"] = next_int_len(4)  # 0x3a
     save_stats["unknown_115"] = next_int_len(8)
 
     save_stats["outbreaks"] = get_outbreaks()
 
     save_stats["unknown_52"] = get_double()
-    save_stats["unknown_53"] = get_length_data()
-    save_stats["unknown_54"] = get_length_data()
+    save_stats["item_schemes"] = {}
+    save_stats["item_schemes"]["to_obtain_ids"] = get_length_data()
+    save_stats["item_schemes"]["received_ids"] = get_length_data()
 
     save_stats["current_outbreaks"] = get_outbreaks()
     save_stats["unknown_55"] = get_mission_data_maybe()
 
-    save_stats["time_stamp_4"] = get_double()  # timestamp
+    save_stats["time_stamp_4"] = get_double()
     save_stats["gv_60"] = next_int_len(4)
 
     save_stats["unknown_117"] = get_unknown_data()
 
     save_stats["gv_61"] = next_int_len(4)
-
     data = get_unlock_popups()
     save_stats["unlock_popups"] = data[0]
 
@@ -1855,8 +2042,7 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
 
     save_stats["tower"] = get_ht_it_data()
     save_stats["missions"] = get_mission_data()
-
-    save_stats["unknown_60"] = get_looped_data()
+    save_stats["tower_item_obtained"] = get_tower_item_obtained()
     save_stats["unknown_61"] = get_data_after_tower()
 
     save_stats["challenge"] = {"Score": next_int_len(4), "Cleared": next_int_len(1)}
@@ -1900,10 +2086,7 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
 
     save_stats["gold_pass"] = get_gold_pass_data()
 
-    data = get_talent_data()
-    save_stats["unknown_69"] = data["dump"]
-
-    save_stats["talents"] = data["talents"]
+    save_stats["talents"] = get_talent_data()
     save_stats["np"] = next_int_len(4)
 
     save_stats["unknown_70"] = next_int_len(1)
@@ -1917,8 +2100,8 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
     save_stats["officer_pass_cat_form"] = next_int_len(2)
 
     save_stats["gv_80200"] = next_int_len(4)  # 80200
-
-    save_stats["unknown_73"] = next_int_len(2)
+    save_stats["filibuster_stage_id"] = next_int_len(1)
+    save_stats["filibuster_stage_enabled"] = next_int_len(1)
 
     save_stats["gv_80300"] = next_int_len(4)  # 80300
 
@@ -1927,6 +2110,14 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
     save_stats["gv_80500"] = next_int_len(4)  # 80500
 
     save_stats["unknown_75"] = get_length_data(2, 4)
+
+    lengths = get_legend_quest_current()
+    save_stats["legend_quest_current"] = lengths
+    save_stats["legend_quest"] = get_legend_quest_progress(lengths)
+
+    save_stats["unknown_133"] = get_length_data(4, 1, lengths["total"])
+    save_stats["legend_quest_ids"] = get_length_data(4, 4, lengths["stages"])
+
     save_stats["unknown_76"] = get_data_after_leadership()
     save_stats["gv_80700"] = next_int_len(4)  # 80700
     if save_stats["dst"]:
@@ -1956,11 +2147,15 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
 
     save_stats["unknown_80"] = get_length_data(4, 1, lengths["total"])
 
-    save_stats["unknown_81"] = get_data_after_gauntlets()
+    save_stats["enigma_data"] = get_enigma_stages()
+    data = get_cleared_slots()
+    save_stats["cleared_slot_data"] = data[0]
+
+    save_stats["unknown_121"] = data[1]
 
     lengths = get_gauntlet_current()
-    save_stats["unknown_82"] = lengths
-    save_stats["unknown_83"] = get_gauntlet_progress(lengths)
+    save_stats["collab_gauntlets_current"] = lengths
+    save_stats["collab_gauntlets"] = get_gauntlet_progress(lengths)
     save_stats["unknown_84"] = get_length_data(4, 1, lengths["total"])
 
     save_stats["unknown_85"] = data_after_after_gauntlets()
@@ -1969,6 +2164,12 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
 
     save_stats["unknown_86"] = get_data_after_orbs()
 
+    save_stats["cat_shrine"] = get_cat_shrine_data()
+
+    save_stats["unknown_130"] = next_int_len(4 * 5)
+
+    save_stats["gv_90900"] = next_int_len(4)  # 90900
+
     save_stats["slot_names"] = get_slot_names(save_stats)
     save_stats["gv_91000"] = next_int_len(4)
     save_stats["legend_tickets"] = next_int_len(4)
@@ -1982,24 +2183,24 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
     save_stats["unknown_90"] = next_int_len(8)
     save_stats["unknown_91"] = next_int_len(8)
 
-    save_stats = check_gv(save_stats, 100000)
-    if save_stats["exit"]:
-        return save_stats
     save_stats["gv_100000"] = next_int_len(4)  # 100000
-
-    save_stats["date_int"] = next_int_len(4)
-
     save_stats = check_gv(save_stats, 100100)
     if save_stats["exit"]:
         return save_stats
+
+    save_stats["date_int"] = next_int_len(4)
+
     save_stats["gv_100100"] = next_int_len(4)  # 100100
-
-    save_stats["unknown_93"] = get_length_data(4, 19, 6)
-
     save_stats = check_gv(save_stats, 100300)
     if save_stats["exit"]:
         return save_stats
+
+    save_stats["unknown_93"] = get_length_data(4, 19, 6)
+
     save_stats["gv_100300"] = next_int_len(4)  # 100300
+    save_stats = check_gv(save_stats, 100700)
+    if save_stats["exit"]:
+        return save_stats
 
     save_stats["unknown_94"] = get_data_near_end()
 
@@ -2007,34 +2208,76 @@ def parse_save(save_data: bytes, country_code: Union[str, None]) -> dict[str, An
 
     save_stats["unknown_100"] = get_data_near_end_after_shards()
 
-    save_stats = check_gv(save_stats, 100700)
+    save_stats["gv_100700"] = next_int_len(4)  # 100700
+    save_stats = check_gv(save_stats, 100900)
     if save_stats["exit"]:
         return save_stats
-    save_stats["gv_100700"] = next_int_len(4)  # 100700
 
     save_stats["aku"] = get_aku()
 
     save_stats["unknown_95"] = next_int_len(1 * 2)
     save_stats["unknown_96"] = get_data_after_aku()
 
-    save_stats = check_gv(save_stats, 100900)
-    if save_stats["exit"]:
-        return save_stats
     save_stats["gv_100900"] = next_int_len(4)  # 100900
-
-    save_stats["unknown_97"] = next_int_len(1)
-
     save_stats = check_gv(save_stats, 101000)
     if save_stats["exit"]:
         return save_stats
+
+    save_stats["unknown_97"] = next_int_len(1)
+
     save_stats["gv_101000"] = next_int_len(4)  # 101000
-
-    save_stats["unknown_98"] = get_data_near_end_after_aku()
-
     save_stats = check_gv(save_stats, 110000)
     if save_stats["exit"]:
         return save_stats
+
+    save_stats["unknown_98"] = get_data_near_end_after_aku()
+
     save_stats["gv_110000"] = next_int_len(4)  # 110000
+    save_stats = check_gv(save_stats, 110500)
+    if save_stats["exit"]:
+        return save_stats
+
+    data = get_gauntlet_current()
+    save_stats["behemoth_culling_current"] = data
+    save_stats["behemoth_culling"] = get_gauntlet_progress(data)
+    save_stats["unknown_124"] = get_length_data(4, 1, data["total"])
+
+    save_stats["unknown_125"] = next_int_len(1)
+
+    save_stats["gv_110500"] = next_int_len(4)  # 110500
+    save_stats = check_gv(save_stats, 110600)
+    if save_stats["exit"]:
+        return save_stats
+
+    save_stats["unknown_126"] = next_int_len(1)
+
+    save_stats["gv_110600"] = next_int_len(4)  # 110600
+    save_stats = check_gv(save_stats, 110700)
+    if save_stats["exit"]:
+        return save_stats
+
+    save_stats["unknown_127"] = get_110700_data()
+
+    if save_stats["dst"]:
+        save_stats["unknown_128"] = next_int_len(1)
+
+    save_stats["gv_110700"] = next_int_len(4)  # 110700
+    save_stats = check_gv(save_stats, 110800)
+    if save_stats["exit"]:
+        return save_stats
+
+    save_stats["shrine_dialogs"] = next_int_len(4)
+
+    save_stats["unknown_129"] = get_110800_data()
+
+    save_stats["dojo_3x_speed"] = next_int_len(1)
+
+    save_stats["unknown_132"] = get_110800_data_2()
+
+    save_stats["gv_110800"] = next_int_len(4)  # 110800
+    save_stats = check_gv(save_stats, 110800)
+    if save_stats["exit"]:
+        return save_stats
 
     length = len(save_data) - address - 32
     save_stats["extra_data"] = next_int_len(length)
