@@ -1,11 +1,12 @@
 """Handler for serialising save data from dict"""
 
 import struct
+import traceback
 from typing import Any, Union
 
 import dateutil.parser
 
-from . import helper, updater
+from . import helper, parse_save
 
 
 def write(
@@ -420,6 +421,47 @@ def serialise_gauntlet_progress(
         save_data = write_length_data(save_data, chapter, 1, 1, False)
     return save_data
 
+def serialise_legend_quest_current(save_data: list[int], legend_quest_current: dict[str, Any]) -> list[int]:
+    save_data = write(save_data, legend_quest_current["total"], 1)
+    save_data = write(save_data, legend_quest_current["stages"], 1)
+    save_data = write(save_data, legend_quest_current["stars"], 1)
+
+    for i in range(len(legend_quest_current["Clear"])):
+        save_data = write_length_data(save_data, legend_quest_current["Clear"][i], 1, 1, False)
+
+    return save_data
+
+def serialise_legend_quest_progress(save_data: list[int], legend_quests: dict[str, Any]) -> list[int]:
+    lengths = legend_quests["Lengths"]
+    total = lengths["total"]
+    stars = lengths["stars"]
+    stages = lengths["stages"]
+
+    for chapter in legend_quests["Value"]["clear_progress"]:
+        save_data = write_length_data(save_data, chapter, 1, 1, False)
+
+    clear_amount = [0] * total * stars * stages
+    clear_amount_data = legend_quests["Value"]["clear_amount"]
+    for i in range(total):
+        for j in range(stages):
+            for k in range(stars):
+                clear_amount[i * stages * stars + j * stars + k] = clear_amount_data[i][k][j]
+    
+    tries = [0] * total * stars * stages
+    tries_data = legend_quests["Value"]["tries"]
+    for i in range(total):
+        for j in range(stages):
+            for k in range(stars):
+                tries[i * stages * stars + j * stars + k] = tries_data[i][k][j]
+    
+
+    save_data = write_length_data(save_data, clear_amount, 4, 2, False)
+    save_data = write_length_data(save_data, tries, 4, 2, False)
+
+    for chapter in legend_quests["Value"]["unlock_next"]:
+        save_data = write_length_data(save_data, chapter, 1, 1, False)
+    return save_data
+
 
 def serialise_talent_orbs(
     save_data: list[int], talent_orbs: dict[str, int], game_verison: dict[str, int]
@@ -522,11 +564,17 @@ def serialise_mission_segment(save_data: list[int], data: dict[int, Any]) -> lis
     return save_data
 
 
-def serialise_missions(save_data: list[int], missions: dict[str, Any]) -> list[int]:
-    save_data = serialise_mission_segment(save_data, missions["flags"])
-    save_data = serialise_mission_segment(save_data, missions["values"])
-    return save_data
+def serialise_missions(save_data: list[int], missions_data: dict[str, Any]) -> list[int]:
+    save_data = serialise_mission_segment(save_data, missions_data["states"])
+    save_data = serialise_mission_segment(save_data, missions_data["requirements"])
+    save_data = serialise_mission_segment(save_data, missions_data["clear_types"])
+    save_data = serialise_mission_segment(save_data, missions_data["gamatoto"])
+    save_data = serialise_mission_segment(save_data, missions_data["nyancombo"])
+    save_data = serialise_mission_segment(save_data, missions_data["user_rank"])
+    save_data = serialise_mission_segment(save_data, missions_data["expiry"])
+    save_data = serialise_mission_segment(save_data, missions_data["preparing"])
 
+    return save_data
 
 def serialise_dojo(save_data: list[int], dojo_data: dict[int, Any]) -> list[int]:
     save_data = write(save_data, len(dojo_data), 4)
@@ -560,14 +608,24 @@ def write_double(save_data: list[int], number: float) -> list[int]:
 def start_serialize(save_stats: dict[str, Any]) -> bytes:
     """Starts the serialisation process"""
 
-    if "editor_version" not in save_stats:
-        raise Exception("No editor version found")
     try:
-        if save_stats["editor_version"] != updater.get_local_version():
-            raise Exception("Editor version mismatch")
         save_data = serialize_save(save_stats)
-    except Exception as err:
-        raise Exception(f"Error serialising save: {err}") from err
+    except Exception:  # pylint: disable=broad-except
+        helper.colored_text(
+            "\nError: An error has occurred while serializing your save data:",
+            base=helper.RED,
+        )
+        traceback.print_exc()
+        game_version = save_stats["game_version"]["Value"]
+        if game_version < 110000:
+            helper.colored_text(
+                f"\nThis save is from before &11.0.0& (current save version is &{helper.gv_to_str(game_version)}&), so this is likely the cause for the issue. &The save editor is not designed to work with saves from before 11.0.0&"
+            )
+        else:
+            helper.colored_text(
+                "\nPlease report this to &#bug-reports&, and/or &dm me your save& on discord"
+            )
+        helper.exit_editor()
     return save_data
 
 
@@ -575,7 +633,7 @@ def serialise_gold_pass(save_data: list[int], gold_pass: dict[str, Any]) -> list
     """Serialises the gold pass data"""
 
     save_data = write(save_data, gold_pass["officer_id"])
-    save_data = write(save_data, gold_pass["flag"])
+    save_data = write(save_data, gold_pass["renewal_times"])
     save_data = write_double(save_data, gold_pass["start_date"])
     save_data = write_double(save_data, gold_pass["expiry_date"])
     save_data = write_length_doubles(
@@ -587,10 +645,23 @@ def serialise_gold_pass(save_data: list[int], gold_pass: dict[str, Any]) -> list
     save_data = write(save_data, gold_pass["flag_2"])
     save_data = write_double(save_data, gold_pass["expiry_date_3"])
 
+    save_data = write(save_data, len(gold_pass["claimed_rewards"]), 4)
+    for item_id, amount in gold_pass["claimed_rewards"].items():
+        save_data = write(save_data, item_id, 4)
+        save_data = write(save_data, amount, 4)
+    
+    save_data = write(save_data, gold_pass["unknown_4"])
+    save_data = write(save_data, gold_pass["unknown_5"])
+    save_data = write(save_data, gold_pass["unknown_6"])
+
     return save_data
 
 
-def serialise_unlock_popups(save_data: list[int], unlock_popups: list[tuple[int, int]], unknown_118: dict[str, int]):
+def serialise_unlock_popups(
+    save_data: list[int],
+    unlock_popups: list[tuple[int, int]],
+    unknown_118: dict[str, int],
+):
     """Serialises the unlock popups"""
 
     save_data = write(save_data, len(unlock_popups), 4)
@@ -601,6 +672,160 @@ def serialise_unlock_popups(save_data: list[int], unlock_popups: list[tuple[int,
     return save_data
 
 
+def serialise_cleared_slots(
+    save_data: list[int], cleared_slots: dict[str, Any]
+) -> list[int]:
+    """
+    Serialises the cleared slots
+
+    Args:
+        save_data (list[int]): The save data
+        cleared_slots (dict[str, Any]): The cleared slots
+
+    Returns:
+        list[int]: The save data
+    """
+    cleared_slot_data = parse_save.ClearedSlots.from_dict(cleared_slots)
+    save_data = write(save_data, len(cleared_slot_data.slots), 2)
+    for slot in cleared_slot_data.slots:
+        save_data = write(save_data, slot.slot_index, 2)
+        for cat in slot.cats:
+            save_data = write(save_data, cat.cat_id, 2)
+            save_data = write(save_data, cat.cat_form, 1)
+        save_data = write(save_data, slot.separator, 3)
+    save_data = write(save_data, cleared_slot_data.end_index, 2)
+
+    for stages_slot in cleared_slot_data.slot_stages:
+        save_data = write(save_data, stages_slot.slot_index, 2)
+        save_data = write(save_data, len(stages_slot.stages), 2)
+        for stage in stages_slot.stages:
+            save_data = write(save_data, stage.stage_id, 4)
+    return save_data
+
+
+def serialise_enigma_data(save_data: list[int], enigma_data: dict[str, Any]):
+    """
+    Serialises the enigma data
+
+    Args:
+        save_data (list[int]): The save data
+        enigma_data (dict[str, Any]): The enigma data
+    """
+    save_data = write(save_data, enigma_data["energy_since_1"], 4)
+    save_data = write(save_data, enigma_data["energy_since_2"], 4)
+    save_data = write(save_data, enigma_data["enigma_level"], 1)
+    save_data = write(save_data, enigma_data["unknown_2"], 1)
+    save_data = write(save_data, enigma_data["unknown_3"], 1)
+
+    save_data = write(save_data, len(enigma_data["stages"]), 1)
+    for stage in enigma_data["stages"]:
+        save_data = write(save_data, stage["level"], 4)
+        save_data = write(save_data, stage["stage_id"], 4)
+        save_data = write(save_data, stage["decoding_status"], 1)
+        save_data = write_double(save_data, stage["start_time"])
+
+    return save_data
+
+
+def serialise_cat_shrine(
+    save_data: list[int], shrine_data: dict[str, Any]
+) -> list[int]:
+    """
+    Serialises the cat shrine data
+
+    Args:
+        save_data (list[int]): The save data
+        shrine_data (dict[str, Any]): The shrine data
+
+    Returns:
+        list[int]: The save data
+    """
+    save_data = write_double(save_data, shrine_data["stamp_1"])
+    save_data = write_double(save_data, shrine_data["stamp_2"])
+    save_data = write(save_data, shrine_data["shrine_gone"], 1)
+    save_data = write_length_data(save_data, shrine_data["flags"], 1, 1)
+    save_data = write(save_data, shrine_data["xp_offering"], 4)
+    return save_data
+
+
+def write_variable_length_int(save_data: list[int], i: int) -> list[int]:
+    """
+    Writes a variable length integer to the save data (I have no idea how this works and what this does)
+
+    Args:
+        save_data (list[int]): The save data
+        i (int): The integer to write
+
+    Returns:
+        list[int]: The save data
+    """
+    i_2 = 0
+    i_3 = 0
+    i = int(i)
+    while i >= 128:
+        i_2 |= ((i & 127) | 32768) << (i_3 * 8)
+        i_3 += 1
+        i >>= 7
+    i_4 = i_2 | (i << (i_3 * 8))
+    i_5 = i_3 + 1
+    for i_6 in range(i_5):
+        i_7 = (i_4 >> (((i_5 - i_6) - 1) * 8)) & 255
+        save_data = write(save_data, i_7, 1)
+    return save_data
+
+
+def set_variable_data(
+    save_data: list[int], data: tuple[dict[int, int], dict[int, int]]
+) -> list[int]:
+    """
+    Sets the variable data
+
+    Args:
+        save_data (list[int]): The save data
+        data (tuple[dict[int, int], dict[int, int]]): The variable data
+
+    Returns:
+        list[int]: The save data
+    """
+    save_data = write_variable_length_int(save_data, len(data[0]))
+    for key, value in data[0].items():
+        save_data = write_variable_length_int(save_data, key)
+        save_data = write_variable_length_int(save_data, value)
+    save_data = write_variable_length_int(save_data, len(data[1]))
+    for key, value in data[1].items():
+        save_data = write_variable_length_int(save_data, key)
+        save_data = write(save_data, value, 1)
+    return save_data
+
+def serialise_login_bonuses(save_data: list[int], login_bonuses: dict[int, int]):
+    """
+    Serialises the login bonuses
+
+    Args:
+        save_data (list[int]): The save data
+        login_bonuses (dict[int, int]): The login bonuses
+    """
+    save_data = write(save_data, len(login_bonuses), 4)
+    for key, value in login_bonuses.items():
+        save_data = write(save_data, key, 4)
+        save_data = write(save_data, value, 4)
+    return save_data
+
+def serialise_tower_item_obtained(save_data: list[int], data: list[list[bool]]):
+    """
+    Serialises the tower item obtained data
+
+    Args:
+        save_data (list[int]): The save data
+        data (list[list[bool]]): The tower item obtained data
+    """
+    save_data = write(save_data, len(data), 4)
+    save_data = write(save_data, len(data[0]), 4)
+    for row in data:
+        for item in row:
+            save_data = write(save_data, item, 1)
+    return save_data
+
 def serialize_save(save_stats: dict[str, Any]) -> bytes:
     """Serialises the save stats"""
 
@@ -610,8 +835,8 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
 
     save_data = write(save_data, save_stats["unknown_1"])
 
-    save_data = write(save_data, save_stats["sound_effects"])
-    save_data = write(save_data, save_stats["music"])
+    save_data = write(save_data, save_stats["mute_music"])
+    save_data = write(save_data, save_stats["mute_sound_effects"])
 
     save_data = write(save_data, save_stats["cat_food"])
     save_data = write(save_data, save_stats["current_energy"])
@@ -693,9 +918,8 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
 
     save_data = serialise_utf8_string(save_data, save_stats["thirty2_code"])
 
-    save_data = write(
-        save_data, save_stats["unknown_10"], save_stats["unknown_10"]["Length"]
-    )
+    save_data = set_variable_data(save_data, save_stats["unknown_10"])
+
     save_data = write_length_data(
         save_data, save_stats["unknown_11"], write_length=False
     )
@@ -737,7 +961,7 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
 
     save_data = write_length_data(save_data, save_stats["unknown_105"], 4, 4, False)
 
-    save_data = write(save_data, save_stats["unknown_107"])
+    save_data = write_length_data(save_data, save_stats["unknown_107"], write_length=False, bytes_per_val=1)
     if save_stats["dst"]:
         save_data = serialise_utf8_string(save_data, save_stats["unknown_110"])
     save_data = write(save_data, len(save_stats["unknown_108"]), 4)
@@ -775,7 +999,7 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     else:
         save_data = write(save_data, save_stats["unknown_24"])
 
-    save_data = write_length_data(save_data, save_stats["catseye_related_data"])
+    save_data = serialise_cat_upgrades(save_data, save_stats["catseye_related_data"])
 
     save_data = write_length_data(
         save_data, save_stats["unknown_22"], write_length=False
@@ -810,8 +1034,9 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     save_data = serialise_play_time(save_data, save_stats["play_time"])
 
     save_data = write(save_data, save_stats["unknown_25"])
-    save_data = write(save_data, save_stats["check_ban_state_succeeded"])
-    save_data = write(save_data, save_stats["unknown_119"])
+    save_data = write(save_data, save_stats["backup_state"])
+    if save_stats["dst"]:
+        save_data = write(save_data, save_stats["unknown_119"])
     save_data = write(save_data, save_stats["gv_44"])
     save_data = write(save_data, save_stats["unknown_120"])
 
@@ -894,10 +1119,15 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     save_data = write(save_data, save_stats["gamatoto_skin"])
     save_data = write(save_data, save_stats["platinum_tickets"])
 
-    save_data = write_length_data(save_data, save_stats["unknown_48"], bytes_per_val=8)
+    save_data = serialise_login_bonuses(save_data, save_stats["login_bonuses"])
     save_data = write(save_data, save_stats["unknown_49"])
     save_data = write_length_data(
-        save_data, save_stats["unknown_50"], write_length=False
+        save_data, save_stats["announcment"], write_length=False
+    )
+    save_data = write(save_data, save_stats["backup_counter"])
+
+    save_data = write_length_data(
+        save_data, save_stats["unknown_131"], write_length=False
     )
 
     save_data = write(save_data, save_stats["gv_55"])
@@ -906,6 +1136,10 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     save_data = serialise_dumped_data(save_data, save_stats["unknown_113"])
 
     save_data = serialise_dojo(save_data, save_stats["dojo_data"])
+    save_data = write(save_data, save_stats["dojo_item_lock"])
+    save_data = write_length_data(
+        save_data, save_stats["dojo_locks"], write_length=False, bytes_per_val=1
+    )
 
     save_data = write(save_data, save_stats["unknown_114"])
 
@@ -916,8 +1150,8 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     save_data = serialise_outbreaks(save_data, save_stats["outbreaks"])
 
     save_data = write_double(save_data, save_stats["unknown_52"])
-    save_data = write_length_data(save_data, save_stats["unknown_53"])
-    save_data = write_length_data(save_data, save_stats["unknown_54"])
+    save_data = write_length_data(save_data, save_stats["item_schemes"]["to_obtain_ids"])
+    save_data = write_length_data(save_data, save_stats["item_schemes"]["received_ids"])
 
     save_data = serialise_outbreaks(save_data, save_stats["current_outbreaks"])
 
@@ -930,7 +1164,9 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
 
     save_data = write(save_data, save_stats["gv_61"])
 
-    save_data = serialise_unlock_popups(save_data, save_stats["unlock_popups"], save_stats["unknown_118"])
+    save_data = serialise_unlock_popups(
+        save_data, save_stats["unlock_popups"], save_stats["unknown_118"]
+    )
 
     save_data = write_length_data(save_data, save_stats["base_materials"])
 
@@ -944,7 +1180,7 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     save_data = serialise_dumped_data(save_data, save_stats["unknown_59"])
     save_data = serialise_tower(save_data, save_stats["tower"])
     save_data = serialise_missions(save_data, save_stats["missions"])
-    save_data = serialise_dumped_data(save_data, save_stats["unknown_60"])
+    save_data = serialise_tower_item_obtained(save_data, save_stats["tower_item_obtained"])
     save_data = serialise_dumped_data(save_data, save_stats["unknown_61"])
     save_data = write(save_data, save_stats["challenge"]["Score"])
     save_data = write(save_data, save_stats["challenge"]["Cleared"])
@@ -982,8 +1218,6 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
 
     save_data = serialise_gold_pass(save_data, save_stats["gold_pass"])
 
-    save_data = serialise_dumped_data(save_data, save_stats["unknown_69"])
-
     save_data = serialise_talent_data(save_data, save_stats["talents"])
     save_data = write(save_data, save_stats["np"])
 
@@ -1000,7 +1234,8 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
 
     save_data = write(save_data, save_stats["gv_80200"])
 
-    save_data = write(save_data, save_stats["unknown_73"])
+    save_data = write(save_data, save_stats["filibuster_stage_id"])
+    save_data = write(save_data, save_stats["filibuster_stage_enabled"])
 
     save_data = write(save_data, save_stats["gv_80300"])
 
@@ -1009,6 +1244,12 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     save_data = write(save_data, save_stats["gv_80500"])
 
     save_data = write_length_data(save_data, save_stats["unknown_75"], 2)
+
+    save_data = serialise_legend_quest_current(save_data, save_stats["legend_quest_current"])
+    save_data = serialise_legend_quest_progress(save_data, save_stats["legend_quest"])
+    save_data = write_length_data(save_data, save_stats["unknown_133"], bytes_per_val = 1, write_length=False)
+    save_data = write_length_data(save_data, save_stats["legend_quest_ids"], write_length=False)
+
     save_data = serialise_dumped_data(save_data, save_stats["unknown_76"])
 
     save_data = write(save_data, save_stats["gv_80700"])
@@ -1036,9 +1277,12 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     save_data = write_length_data(
         save_data, save_stats["unknown_80"], bytes_per_val=1, write_length=False
     )
-    save_data = serialise_dumped_data(save_data, save_stats["unknown_81"])
-    save_data = serialise_gauntlet_current(save_data, save_stats["unknown_82"])
-    save_data = serialise_gauntlet_progress(save_data, save_stats["unknown_83"])
+    save_data = serialise_enigma_data(save_data, save_stats["enigma_data"])
+    save_data = serialise_cleared_slots(save_data, save_stats["cleared_slot_data"])
+
+    save_data = serialise_dumped_data(save_data, save_stats["unknown_121"])
+    save_data = serialise_gauntlet_current(save_data, save_stats["collab_gauntlets_current"])
+    save_data = serialise_gauntlet_progress(save_data, save_stats["collab_gauntlets"])
     save_data = write_length_data(
         save_data, save_stats["unknown_84"], bytes_per_val=1, write_length=False
     )
@@ -1050,6 +1294,13 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     )
 
     save_data = serialise_dumped_data(save_data, save_stats["unknown_86"])
+
+    save_data = serialise_cat_shrine(save_data, save_stats["cat_shrine"])
+
+    save_data = write(save_data, save_stats["unknown_130"])
+
+    save_data = write(save_data, save_stats["gv_90900"])
+
     if save_stats["game_version"]["Value"] >= 110600:
         save_data = write(save_data, len(save_stats["slot_names"]), 1)
     for slot_name in save_stats["slot_names"]:
@@ -1069,66 +1320,113 @@ def serialize_save(save_stats: dict[str, Any]) -> bytes:
     save_data = write(save_data, save_stats["unknown_90"])
     save_data = write(save_data, save_stats["unknown_91"])
 
-    data = check_gv(save_data, save_stats, 100000)
-    save_data = data["save_data"]
-    if data["exit"]:
-        return bytes(save_data)
     save_data = write(save_data, save_stats["gv_100000"])
-
-    save_data = write(save_data, save_stats["date_int"])
-
     data = check_gv(save_data, save_stats, 100100)
     save_data = data["save_data"]
     if data["exit"]:
         return bytes(save_data)
+
+    save_data = write(save_data, save_stats["date_int"])
+
     save_data = write(save_data, save_stats["gv_100100"])
+    data = check_gv(save_data, save_stats, 100300)
+    save_data = data["save_data"]
+    if data["exit"]:
+        return bytes(save_data)
 
     save_data = write_length_data(
         save_data, save_stats["unknown_93"], bytes_per_val=19, write_length=False
     )
 
-    data = check_gv(save_data, save_stats, 100300)
+    save_data = write(save_data, save_stats["gv_100300"])
+    data = check_gv(save_data, save_stats, 100700)
     save_data = data["save_data"]
     if data["exit"]:
         return bytes(save_data)
-    save_data = write(save_data, save_stats["gv_100300"])
 
     save_data = serialise_dumped_data(save_data, save_stats["unknown_94"])
     save_data = write(save_data, save_stats["platinum_shards"])
     save_data = serialise_dumped_data(save_data, save_stats["unknown_100"])
 
-    data = check_gv(save_data, save_stats, 100700)
+    save_data = write(save_data, save_stats["gv_100700"])
+    data = check_gv(save_data, save_stats, 100900)
     save_data = data["save_data"]
     if data["exit"]:
         return bytes(save_data)
-    save_data = write(save_data, save_stats["gv_100700"])
 
     save_data = serialise_aku(save_data, save_stats["aku"])
 
     save_data = write(save_data, save_stats["unknown_95"])
     save_data = serialise_dumped_data(save_data, save_stats["unknown_96"])
 
-    data = check_gv(save_data, save_stats, 100900)
-    save_data = data["save_data"]
-    if data["exit"]:
-        return bytes(save_data)
     save_data = write(save_data, save_stats["gv_100900"])
-
-    save_data = write(save_data, save_stats["unknown_97"])
-
     data = check_gv(save_data, save_stats, 101000)
     save_data = data["save_data"]
     if data["exit"]:
         return bytes(save_data)
+
+    save_data = write(save_data, save_stats["unknown_97"])
+
     save_data = write(save_data, save_stats["gv_101000"])
-
-    save_data = serialise_dumped_data(save_data, save_stats["unknown_98"])
-
     data = check_gv(save_data, save_stats, 110000)
     save_data = data["save_data"]
     if data["exit"]:
         return bytes(save_data)
+
+    save_data = serialise_dumped_data(save_data, save_stats["unknown_98"])
+
     save_data = write(save_data, save_stats["gv_110000"])
+    data = check_gv(save_data, save_stats, 110500)
+    save_data = data["save_data"]
+    if data["exit"]:
+        return bytes(save_data)
+
+    save_data = serialise_gauntlet_current(save_data, save_stats["behemoth_culling_current"])
+    save_data = serialise_gauntlet_progress(save_data, save_stats["behemoth_culling"])
+    save_data = write_length_data(
+        save_data, save_stats["unknown_124"], bytes_per_val=1, write_length=False
+    )
+
+    save_data = write(save_data, save_stats["unknown_125"])
+
+    save_data = write(save_data, save_stats["gv_110500"])
+    data = check_gv(save_data, save_stats, 110600)
+    save_data = data["save_data"]
+    if data["exit"]:
+        return bytes(save_data)
+
+    save_data = write(save_data, save_stats["unknown_126"])
+
+    save_data = write(save_data, save_stats["gv_110600"])
+    data = check_gv(save_data, save_stats, 110700)
+    save_data = data["save_data"]
+    if data["exit"]:
+        return bytes(save_data)
+
+    save_data = serialise_dumped_data(save_data, save_stats["unknown_127"])
+
+    if save_stats["dst"]:
+        save_data = write(save_data, save_stats["unknown_128"])
+
+    save_data = write(save_data, save_stats["gv_110700"])
+    data = check_gv(save_data, save_stats, 110800)
+    save_data = data["save_data"]
+    if data["exit"]:
+        return bytes(save_data)
+
+    save_data = write(save_data, save_stats["shrine_dialogs"])
+
+    save_data = serialise_dumped_data(save_data, save_stats["unknown_129"])
+
+    save_data = write(save_data, save_stats["dojo_3x_speed"])
+
+    save_data = serialise_dumped_data(save_data, save_stats["unknown_132"])
+
+    save_data = write(save_data, save_stats["gv_110800"])
+    data = check_gv(save_data, save_stats, 110800)
+    save_data = data["save_data"]
+    if data["exit"]:
+        return bytes(save_data)
 
     save_data = write(save_data, save_stats["extra_data"])
 
