@@ -2,8 +2,6 @@
 
 from typing import Any, Tuple, Union
 
-from pick import pick
-
 from . import helper, config_manager
 
 
@@ -136,22 +134,6 @@ def select_options(
     if len(options) == 1:
         return [0], True
 
-    if config_manager.get_config_value_category(
-        "EDITOR", "USE_ARROW_KEYS_FOR_FEATURE_SELECT"
-    ):
-        options.append("Select all")
-        choice_data: list[tuple[str, int]] = pick(
-            options,
-            f"Select options to {mode} (Use the arrow keys, or j and k to move the cursor. Press space to select, then enter to confirm)",
-            indicator="->",
-            multiselect=True,
-            min_selection_count=1,
-        )
-        ids = [x[1] for x in choice_data]
-        if len(options) - 1 in ids:
-            return list(range(len(options) - 1)), False
-        return ids, True
-
     helper.colored_list(options, extra_data=extra_data, offset=offset)
     total = len(options)
     helper.colored_text(f"{total+1}. &Select all&")
@@ -165,6 +147,13 @@ def select_options(
         ids_s = helper.int_to_str_ls(ids)
 
     ids = helper.parse_int_list(ids_s, -1)
+    for item_id in ids:
+        if item_id < 0 or item_id > total - 1:
+            helper.colored_text(
+                f"Invalid input. Please enter a valid integer between 1 and {total+1}.",
+                helper.RED,
+            )
+            return select_options(options, mode, extra_data, offset)
     return ids, individual
 
 
@@ -193,17 +182,31 @@ def select_single(
     options: list[str],
     mode: str = "edit",
     title: str = "",
+    allow_text: bool = False,
 ) -> int:
     "Select a single option from a list"
-    if config_manager.get_config_value_category(
-        "EDITOR", "USE_ARROW_KEYS_FOR_FEATURE_SELECT"
-    ):
-        option_data: tuple[str, int] = pick(options, title + "\nMove cursor with arrow keys, or j and k. Press enter to select an option", indicator="->")  # type: ignore
-        return option_data[1] + 1
+    if not options:
+        raise ValueError("No options to select from")
+    if len(options) == 1:
+        return 1
     helper.colored_list(options)
     if not title:
         title = f"Select an option to {mode}:"
-    return get_int(title)
+    val = colored_input(title)
+    if allow_text:
+        if val in options:
+            return options.index(val) + 1
+    val = helper.check_int(val)
+    if val is None:
+        helper.colored_text("Invalid input. Please enter a valid integer.", helper.RED)
+        return select_single(options, mode, title, allow_text)
+    if val < 1 or val > len(options):
+        helper.colored_text(
+            f"Invalid input. Please enter an integer between 1 and {len(options)}.",
+            helper.RED,
+        )
+        return select_single(options, mode, title, allow_text)
+    return val
 
 
 def get_int(dialog: str) -> int:
